@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: check_if_0.sh 2082 2011-08-31 17:50:58Z bradbell $
+# $Id: check_if_0.sh 2537 2012-11-04 13:43:48Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -23,8 +23,8 @@ echo "-------------------------------------------------------"
 ok="yes"
 for ext in .cpp .hpp
 do
-	dir_list=`find . -name "*$ext" | \
-		sed -e 's|^\./||' -e '/^work/d' -e 's|/[^/]*$||' | sort -u`  
+	dir_list=`find . -name "*$ext" | sed -e '/junk\.[^.]*$/d' \
+		-e 's|^\./||' -e '/^work/d' -e 's|/[^/]*$||' | sort -u`  
 	for dir in $dir_list 
 	do
 		list=`ls $dir/*$ext`
