@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: check_include_file.sh 2082 2011-08-31 17:50:58Z bradbell $
+# $Id: check_include_file.sh 2683 2012-12-30 18:17:03Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -27,8 +27,8 @@ then
 fi
 for ext in .cpp .hpp
 do
-	dir_list=`find . -name "*$ext" | \
-		sed -e 's|^\./||' -e '/^work/d' -e 's|/[^/]*$||' | sort -u`  
+	dir_list=`find . -name "*$ext" | sed -e '/junk\.[^.]*$/d' \
+		-e 's|^\./||' -e '/^work/d' -e 's|/[^/]*$||' | sort -u`  
 	for dir in $dir_list 
 	do
 		list=`ls $dir/*$ext`
@@ -46,9 +46,12 @@ cat bin/check_include_file.1.$$ | \
 # The file cppad/local/prototype_op.hpp should never be included. 
 # All other files should.
 ls	cppad/*.hpp \
+	cppad/example/*.hpp \
+	cppad/ipopt/*.hpp \
 	cppad/local/*.hpp \
-	cppad/speed/*.hpp | \
-		sed -e '/cppad\/local\/prototype_op.hpp/d' | \
+	cppad/speed/*.hpp | sed \
+		-e '/cppad\/local\/prototype_op.hpp/d' \
+		-e '/cppad\/example\/eigen_plugin.hpp/d' | \
 		sort > bin/check_include_file.3.$$ 
 if diff bin/check_include_file.2.$$ bin/check_include_file.3.$$
 then
