@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: check_include_omh.sh 2178 2011-10-30 06:52:58Z bradbell $
+# $Id: check_include_omh.sh 2586 2012-11-19 06:56:04Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -20,21 +20,18 @@ fi
 echo "Checking difference between OMhelp include directives and file names."
 echo "----------------------------------------------------------------------"
 # super list of file names that are referenced by omhelp commands
-find . \( -name '*.cpp' \) -or \
+find . \( -name '*.c'   \) -or \
+       \( -name '*.cpp' \) -or \
        \( -name '*.hpp' \) -or \
        \( -name '*.omh' \) -or \
-       \( -name '*.am' \) | \
-	sed -e '/.\/work\//d' -e '/.\/new\//d' -e '/.\/doc\//d' -e 's|./||' \
+       \( -name '*.txt' \) -or \
+       \( -name '*.am' \) | sed \
+		-e '/.\/work\//d' \
+		-e '/.\/build\//d' \
+		-e '/.\/new\//d' \
+		-e '/.\/doc\//d' \
+		-e 's|./||' \
 		> bin/check_include_omh.1.$$
-list="
-	cpl1.0.txt
-	cppad_ipopt/example/example_windows.bat
-	gpl2.txt
-"
-for file in $list
-do
-	echo $file >> bin/check_include_omh.1.$$
-done
 for file in `cat bin/check_include_omh.1.$$`
 do
 	# assume $childtable, ... , $verbatim use % for delimiter
