@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: check_makefile.sh 2200 2011-11-22 05:03:01Z bradbell $
+# $Id: check_makefile.sh 2683 2012-12-30 18:17:03Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -18,7 +18,13 @@ fi
 # -----------------------------------------------------------------------------
 echo "Checking include files listed in makefile.am"
 echo "-------------------------------------------------------" 
-ls cppad/*.h cppad/*.hpp cppad/local/*.hpp cppad/speed/*.hpp  | \
+ls \
+	cppad/*.h \
+	cppad/*.hpp \
+	cppad/example/*.hpp \
+	cppad/local/*.hpp \
+	cppad/ipopt/*.hpp \
+	cppad/speed/*.hpp  | \
 	sed -e '/^cppad\/config\.h$/d' | \
 	sort > check_makefile1.$$
 #
@@ -49,7 +55,8 @@ fi
 # -----------------------------------------------------------------------------
 echo "Checking debugging flags in all makefile.am files."
 echo "-------------------------------------------------------" 
-list=`find . -name makefile.am | sed -e 's|\./||'`
+list=`find . -name makefile.am | \
+	sed -e '/\/build\//d' -e'/\/work\//d' -e 's|\./||'`
 ok="yes"
 for file in $list
 do
@@ -101,6 +108,19 @@ do
 		fi
 		;;
 
+		(compare_c/makefile.am)
+		if ! grep '^[^#]*-DNDEBUG' $file > /dev/null
+		then
+			echo "Optimization flag is not defined in $file"
+			ok="no"
+		fi
+		if ! grep '^#.*-g' $file > /dev/null
+		then
+			echo "Debug flag is not commented out in $file"
+			ok="no"
+		fi
+		;;
+
 		*)
 		if grep '\-DNDEBUG' $file > /dev/null
 		then
