@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: commit.sh 2239 2011-12-31 00:40:19Z bradbell $
+# $Id: commit.sh 2688 2012-12-30 20:17:42Z bradbell $
 # -----------------------------------------------------------------------------
 # CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -81,9 +81,13 @@ unknown=`svn status | sed -n \
 	-e '/^[?].*\.am$/p'  \
 	-e '/^[?].*\.cpp$/p'  \
 	-e '/^[?].*\.hpp$/p'  \
+	-e '/^[?].*\.html$/p'  \
 	-e '/^[?].*\.in$/p'  \
 	-e '/^[?].*\.omh$/p'  \
-	-e '/^[?].*\.sh$/p'   | sed -e 's/^[?]//'`
+	-e '/^[?].*\.pc$/p'  \
+	-e '/^[?].*\.py$/p'  \
+	-e '/^[?].*\.sh$/p'   \
+	-e '/^[?].*\.txt$/p'  | sed -e 's/^[?]//'`
 msg="aborting because the following files are unknown to svn"
 print_msg="no"
 for file in $unknown
@@ -105,8 +109,8 @@ then
 fi
 # -------------------------------------------------
 # list of files that changed
-svn status | sed -n -e '/^[ADMRC] /p' | \
-	sed -e 's/^[ADMRC] [+ ]*//' \
+svn status | sed -n -e '/^[ADMRC][ADMRC]* /p' | \
+	sed -e 's/^[ADMRC][ADMRC]* [+ ]*//' \
 		-e '/^bin\/commit.sh$/d' -e '/^bin\/commit.sed$/d' | \
 	sort -u > bin/commit.list.$$
 # -------------------------------------------------
@@ -123,13 +127,10 @@ then
 	list=`cat bin/commit.list.$$`
 	for file in $list
 	do
-		# exclude */makefile.in and *.vcproj files
-		# from edits in bin/commit.sed
+		# exclude */makefile.in from edits in bin/commit.sed
 		local_file=`echo $file | sed -e 's|.*/||'`
 		file_ext=`echo $file | sed -e 's|.*\.||'`
-		if [ -f "$file" ] &&  \
-		   [ "$local_file" != "makefile.in" ] && \
-		   [ "$file_ext" != "vcproj" ]
+		if [ -f "$file" ] &&  [ "$local_file" != "makefile.in" ]
 		then
 			sed -f bin/commit.sed $file > bin/commit.tmp.$$
 			if ! diff $file bin/commit.tmp.$$ > /dev/null
@@ -207,13 +208,6 @@ then
 	exit 1
 fi
 #
-sed -f bin/commit.sed cppad/configure.hpp > bin/commit.tmp.$$
-if ! diff cppad/configure.hpp bin/commit.tmp.$$
-then
-	echo "bin/commit.sh run: unexpected values in cppad/configure.hpp"
-	rm bin/commit.*.$$
-	exit 1
-fi
 rm bin/commit.*.$$
 #
 echo "svn commit -m \""
