@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: new_release.sh 2603 2012-12-14 17:33:23Z bradbell $
+# $Id: new_release.sh 2907 2013-10-06 14:20:31Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -15,10 +15,15 @@ then
 	echo "bin/new_release.sh: must be executed from its parent directory"
 	exit 1
 fi
+# bash function that echos and executes a command
+echo_eval() {
+	echo $*
+	eval $*
+}
 # -----------------------------------------------------------------------------
 repository="https://projects.coin-or.org/svn/CppAD"
-stable_version="20120101"
-release="4"
+stable_version="20130000"
+release='3'
 release_version="$stable_version.$release"
 msg="Creating releases/$release_version"
 # -----------------------------------------------------------------------------
@@ -27,7 +32,7 @@ dir=`pwd | sed -e 's|.*/[Cc][Pp][Pp][Aa][Dd]/||'`
 check="stable/$stable_version"
 if [ "$dir" != "$check" ]
 then
-	echo bin/"new_stable.sh: must execute this script in $check"
+	echo bin/"new_release.sh: must execute this script in $check"
 	exit 1
 fi
 # -----------------------------------------------------------------------------
@@ -40,56 +45,39 @@ then
 	echo "in file bin/new_release.sh to a higher release number."
 	exit 1
 fi
-echo "svn revert configure.ac"
-      svn revert configure.ac
-if ! grep "AC_INIT(CppAD.*, $release_version" configure.ac > /dev/null
+#
+check_one=`bin/version.sh get`
+echo_eval svn revert doc.omh
+check_two=`grep "cppad-$stable_version" doc.omh \
+	| sed -e 's|cppad-\([0-9.]*\):.*|\1|'`
+if [ "$check_one" != "$release_version" ] || [ "$check_one" != "$check_two" ]
 then
-	echo bin/"new_release.sh: Change version number in configure.ac to be"
-	echo "$release_version, then execute"
-	echo "	./build.sh version automake configure"
-	echo "then commit the changes."
-	exit 1
-fi
-echo "svn revert cppad/configure.hpp"
-      svn revert cppad/configure.hpp
-if ! grep "PACKAGE_STRING *\"cppad-$release_version\"" \
-	cppad/configure.hpp > /dev/null
-then
-	echo bin/"new_release.sh: Version in cppad/configure.hpp not $release_version."
-	echo "	./build.sh version automake configure"
-	echo "should fix this."
-	exit 1
-fi
-# -----------------------------------------------------------------------------
-# check stable version 
-dir=`pwd | sed -e 's|.*/[Cc][Pp][Pp][Aa][Dd]/||'`
-if [ "$dir" != "stable/$stable_version" ]
-then
-	echo bin/"new_release.sh: must execute this command in stable/$stable_version"
+	echo 'bin/new_release.sh:'
+	echo 'Set new version number with following commands:'
+	echo "	bin/version.sh set $release_version"
+	echo '	bin/version.sh copy'
+	echo 'then test and then commit the changes.'
 	exit 1
 fi
 # -----------------------------------------------------------------------------
 rep_stable="$repository/stable/$stable_version"
 rep_release="$repository/releases/$release_version"
-echo "svn copy $rep_stable $rep_release -m \"$msg\""
-      svn copy $rep_stable $rep_release -m "$msg"
+echo_eval svn copy $rep_stable $rep_release -m \"$msg\"
 # -----------------------------------------------------------------------------
 echo "cd ../.."
 cd ../..
 #
 if [ -e conf ]
 then
-	echo "rm -rf conf"
-	      rm -rf conf
+	echo_eval rm -rf conf.old
+	echo_eval mv conf conf.old
 fi
-echo "svn checkout $repository/conf conf"
-      svn checkout $repository/conf conf
+echo_eval svn checkout $repository/conf conf
 #
-echo "cd conf"
-      cd conf
+echo_eval cd conf
 #
 msg="Update stable and release numbers in projDesc.xml"
-echo bin/"new_release.sh: $msg"
+echo 'Settting stable and advance release in ../../conf/projDesc.xml.'
 sed -i projDesc.xml \
 	-e "/^ *<stable/,/^ *<\/stable/s/[0-9]\{8\}/$stable_version/" \
 	-e "/^ *<release/,/^ *<\/release/s/[0-9]\{8\}\.[0-9]*/$release_version/"
