@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: run_omhelp.sh 2082 2011-08-31 17:50:58Z bradbell $
+# $Id: run_omhelp.sh 2568 2012-11-14 15:50:13Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -52,7 +52,7 @@ if [ "$2" == "printable" ]
 then
 	cmd="$cmd -printable"
 fi
-echo "$cmd > ../omhelp.$ext.log"
+echo "$cmd > omhelp.$ext.log"
 if !  $cmd > ../omhelp.$ext.log
 then
 	grep "^OMhelp Error:" ../omhelp.$ext.log
