@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: search.sh 2082 2011-08-31 17:50:58Z bradbell $
+# $Id: search.sh 2691 2012-12-30 23:39:57Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -22,10 +22,15 @@ then
 	exit 1
 fi
 pattern="$1"
-extensions='.ac .am .cpp .hpp .in .omh .sh'
+extensions='.ac .am .cpp .hpp .in .omh .pc .sh .txt'
 directories='
+	.
+	bin
 	cppad 
+	cppad/example 
+	cppad/ipopt
 	cppad/local 
+	cppad/speed 
 	cppad_ipopt/example
 	cppad_ipopt/speed
 	cppad_ipopt/src
@@ -38,6 +43,8 @@ directories='
 	multi_thread/openmp
 	multi_thread/pthread
 	omh
+	omh/deprecated
+	omh/whats_new
 	pkgconfig
 	print_for
 	speed
@@ -52,4 +59,5 @@ directories='
 	test_more 
 '
 #
-find_files.sh "$pattern" "$extensions" "$directories"
+find_files.sh "$pattern" "$extensions" "$directories" | \
+	 sed -e '/\/makefile.in/d'
