@@ -1,11 +1,11 @@
 #! /bin/bash -e
-# $Id: svn_merge.sh 2178 2011-10-30 06:52:58Z bradbell $
+# $Id: svn_merge.sh 2506 2012-10-24 19:36:49Z bradbell $
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 #
 # CppAD is distributed under multiple licenses. This distribution is under
 # the terms of the
-#                     GNU General Public License Version 2.
+#                     GNU General Public License Version 3.
 #
 # A copy of this license is included in the COPYING file of this distribution.
 # Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -27,18 +27,20 @@ fi
 echo "DryRun = $DryRun"
 #
 # script to help in execution of svn merge command
+# 
+# Location of the repository
+repository='https://projects.coin-or.org/svn/CppAD'
 #
 # Name of the directory where the changes have been committed
-from_branch=branches/thread
+from_branch='branches/sparse'
 #
 # Version of the repository corresponding to from_branch just before changes
-Start=2124
+Start=2474
 # 
 # Version of the repository corresponding to from_branch after the changes
-End=2177
+End=2479
 #
 # the svn merge command
-cmd="svn merge $DryRun -r $Start:$End"
-cmd="$cmd https://projects.coin-or.org/svn/CppAD/$from_branch"
+cmd="svn merge $DryRun -r $Start:$End $repository/$from_branch"
 echo "$cmd"
 $cmd
