@@ -1,13 +1,13 @@
-/* $Id: ad.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
+/* $Id: ad.hpp 2692 2012-12-31 01:27:34Z bradbell $ */
 # ifndef CPPAD_AD_INCLUDED
 # define CPPAD_AD_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -25,6 +25,12 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 
+typedef enum {
+	tape_manage_new, 
+	tape_manage_delete, 
+	tape_manage_clear
+} tape_manage_job;
+
 template <class Base>
 class AD {
 	// enable use of AD<Base> in parallel mode
@@ -123,6 +129,10 @@ class AD {
 	friend bool operator != <Base>
 		(const AD<Base> &left, const AD<Base> &right);
 
+	// input operator
+	friend std::istream& operator >> <Base>
+		(std::istream &is, AD<Base> &x);
+
 	// output operations
 	friend std::ostream& operator << <Base>
 		(std::ostream &os, const AD<Base> &x);
@@ -180,6 +190,7 @@ public:
 	inline AD cos(void) const;
 	inline AD cosh(void) const;
 	inline AD exp(void) const;
+	inline AD fabs(void) const;
 	inline AD log(void) const;
 	inline AD sin(void) const;
 	inline AD Sign(void) const;
@@ -215,10 +226,7 @@ private:
 	Base value_;
 
 	// Tape identifier corresponding to taddr
-	// This is a variable if and only if id_ == *id_handle()
-	// For parameters id_ is CPPAD_MAX_NUM_THREADS, so that following hold
-	// id_ != 0 , id_ % CPPAD_MAX_NUM_THREADS == 0, id_ != *id_handle().
-	CPPAD_TAPE_ID_TYPE id_;
+	tape_id_t tape_id_;
 
 	// taddr_ in tape for this variable 
 	addr_t taddr_;
@@ -227,7 +235,7 @@ private:
 	//
 	void make_parameter(void)
 	{	CPPAD_ASSERT_UNKNOWN( Variable(*this) );  // currently a var
-		id_ = CPPAD_MAX_NUM_THREADS;
+		tape_id_ = 0;
 	}
 	//
 	// Make this parameter a new variable 
@@ -236,22 +244,22 @@ private:
 	{	CPPAD_ASSERT_UNKNOWN( Parameter(*this) ); // currently a par
 		CPPAD_ASSERT_UNKNOWN( taddr > 0 );        // sure valid taddr
 
-		taddr_ = taddr;
-		id_    = id;
+		taddr_   = taddr;
+		tape_id_ = id;
 	}
 	// ---------------------------------------------------------------
 	// tape linking functions
 	// 
 	// not static
-	inline ADTape<Base> *tape_this(void) const;
+	inline ADTape<Base>* tape_this(void) const;
 	//
 	// static 
-	inline static size_t        *id_handle (size_t thread);
-	inline static ADTape<Base> **tape_handle(size_t thread);
-	static size_t                tape_new(void);
-	static void                  tape_delete(size_t id);
-	inline static ADTape<Base>  *tape_ptr(void);
-	inline static ADTape<Base>  *tape_ptr(size_t id);
+	inline static tape_id_t**    tape_id_handle(size_t thread);
+	inline static tape_id_t*     tape_id_ptr(size_t thread);
+	inline static ADTape<Base>** tape_handle(size_t thread);
+	static ADTape<Base>*         tape_manage(tape_manage_job job);
+	inline static ADTape<Base>*  tape_ptr(void);
+	inline static ADTape<Base>*  tape_ptr(tape_id_t tape_id);
 }; 
 // ---------------------------------------------------------------------------
 
