@@ -1,13 +1,13 @@
-/* $Id: ad_tape.hpp 2038 2011-07-31 23:56:44Z bradbell $ */
+/* $Id: ad_tape.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
 # ifndef CPPAD_AD_TAPE_INCLUDED
 # define CPPAD_AD_TAPE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -96,7 +96,7 @@ private:
 	been deleted). In addition, id_ % CPPAD_MAX_NUM_THREADS is the thread 
 	number for this tape. Set by Independent and effectively const
 	*/
-	size_t                       id_;
+	tape_id_t                    id_;
 	/// Number of independent variables in this tapes reconding.
 	/// Set by Independent and effectively const
 	size_t         size_independent_;
@@ -133,13 +133,7 @@ private:
 	);
 
 public:
-	// constructor
-	ADTape(size_t id) : id_(id)
-	{ }
-
-	// destructor
-	~ADTape(void)
-	{	Rec_.Erase(); }
+	// default constructor and destructor
 
 	// public function only used by CppAD::Independent
 	template <typename VectorADBase>
