@@ -1,13 +1,13 @@
-/* $Id: bool_fun.hpp 1824 2011-01-23 04:14:54Z bradbell $ */
+/* $Id: bool_fun.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_BOOL_FUN_INCLUDED
 # define CPPAD_BOOL_FUN_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -30,63 +30,63 @@ $index binary, AD bool$$
 $section AD Boolean Functions$$
 
 $head Syntax$$
-$syntax%CPPAD_BOOL_UNARY(%Base%, %unary_name%)
+$codei%CPPAD_BOOL_UNARY(%Base%, %unary_name%)
 %$$
-$syntax%%b% = %unary_name%(%u%)
+$icode%b% = %unary_name%(%u%)
 %$$
-$syntax%%b% = %unary_name%(%x%)
+$icode%b% = %unary_name%(%x%)
 %$$
-$syntax%CPPAD_BOOL_BINARY(%Base%, %binary_name%)
+$codei%CPPAD_BOOL_BINARY(%Base%, %binary_name%)
 %$$
-$syntax%%b% = %binary_name%(%u%, %v%)
+$icode%b% = %binary_name%(%u%, %v%)
 %$$
-$syntax%%b% = %binary_name%(%x%, %y%)%$$
+$icode%b% = %binary_name%(%x%, %y%)%$$
 
 
 $head Purpose$$
-Create a $code bool$$ valued function that has $syntax%AD<%Base%>%$$ arguments.
+Create a $code bool$$ valued function that has $codei%AD<%Base%>%$$ arguments.
 
 $head unary_name$$
 This is the name of the $code bool$$ valued function with one argument
 (as it is used in the source code).
-The user must provide a version of $italic unary_name$$ where
-the argument has type $italic Base$$.
-CppAD uses this to create a version of $italic unary_name$$ where the
-argument has type $syntax%AD<%Base%>%$$.
+The user must provide a version of $icode unary_name$$ where
+the argument has type $icode Base$$.
+CppAD uses this to create a version of $icode unary_name$$ where the
+argument has type $codei%AD<%Base%>%$$.
 
 $head u$$
-The argument $italic u$$ has prototype
-$syntax%
+The argument $icode u$$ has prototype
+$codei%
 	const %Base% &%u%
 %$$
-It is the value at which the user provided version of $italic unary_name$$
+It is the value at which the user provided version of $icode unary_name$$
 is to be evaluated.
 It is also used for the first argument to the 
-user provided version of $italic binary_name$$.
+user provided version of $icode binary_name$$.
 
 $head x$$
-The argument $italic x$$ has prototype
-$syntax%
+The argument $icode x$$ has prototype
+$codei%
 	const AD<%Base%> &%x%
 %$$
-It is the value at which the CppAD provided version of $italic unary_name$$
+It is the value at which the CppAD provided version of $icode unary_name$$
 is to be evaluated.
 It is also used for the first argument to the 
-CppAD provided version of $italic binary_name$$.
+CppAD provided version of $icode binary_name$$.
 
 $head b$$
-The result $italic b$$ has prototype
-$syntax%
+The result $icode b$$ has prototype
+$codei%
 	bool %b%
 %$$
 
 $head Create Unary$$
 $index CPPAD_BOOL_UNARY$$
 The preprocessor macro invocation
-$syntax%
+$codei%
 	CPPAD_BOOL_UNARY(%Base%, %unary_name%)
 %$$
-defines the version of $italic unary_name$$ with a $syntax%AD<%Base%>%$$
+defines the version of $icode unary_name$$ with a $codei%AD<%Base%>%$$
 argument.
 This can with in a namespace 
 (not the $code CppAD$$ namespace)
@@ -95,34 +95,34 @@ but must be outside of any routine.
 $head binary_name$$
 This is the name of the $code bool$$ valued function with two arguments
 (as it is used in the source code).
-The user must provide a version of $italic binary_name$$ where
-the arguments have type $italic Base$$.
-CppAD uses this to create a version of $italic binary_name$$ where the
-arguments have type $syntax%AD<%Base%>%$$.
+The user must provide a version of $icode binary_name$$ where
+the arguments have type $icode Base$$.
+CppAD uses this to create a version of $icode binary_name$$ where the
+arguments have type $codei%AD<%Base%>%$$.
 
 $head v$$
-The argument $italic v$$ has prototype
-$syntax%
+The argument $icode v$$ has prototype
+$codei%
 	const %Base% &%v%
 %$$
 It is the second argument to
-the user provided version of $italic binary_name$$.
+the user provided version of $icode binary_name$$.
 
 $head y$$
-The argument $italic x$$ has prototype
-$syntax%
+The argument $icode x$$ has prototype
+$codei%
 	const AD<%Base%> &%y%
 %$$
 It is the second argument to
-the CppAD provided version of $italic binary_name$$.
+the CppAD provided version of $icode binary_name$$.
 
 $head Create Binary$$
 $index CPPAD_BOOL_BINARY$$
 The preprocessor macro invocation
-$syntax%
+$codei%
 	CPPAD_BOOL_BINARY(%Base%, %binary_name%)
 %$$
-defines the version of $italic binary_name$$ with $syntax%AD<%Base%>%$$
+defines the version of $icode binary_name$$ with $codei%AD<%Base%>%$$
 arguments.
 This can with in a namespace 
 (not the $code CppAD$$ namespace)
@@ -131,17 +131,17 @@ but must be outside of any routine.
 
 $head Operation Sequence$$
 The result of this operation is not an
-$xref/glossary/AD of Base/AD of Base/$$ object.
+$cref/AD of Base/glossary/AD of Base/$$ object.
 Thus it will not be recorded as part of an
-AD of $italic Base$$
-$xref/glossary/Operation/Sequence/operation sequence/1/$$.
+AD of $icode Base$$
+$cref/operation sequence/glossary/Operation/Sequence/$$.
 
 $head Example$$
 $children%
 	example/bool_fun.cpp
 %$$
 The file
-$xref/BoolFun.cpp/$$
+$cref bool_fun.cpp$$
 contains an example and test of these operations.
 It returns true if it succeeds and false otherwise.
 
@@ -156,13 +156,12 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup bool_fun_hpp bool_fun.hpp
+\{
 \file bool_fun.hpp
 Routines and macros that implement functions from AD<Base> to bool
 \ref bool_fun_hpp.
-
-\defgroup bool_fun_hpp bool_fun.hpp
 */
-/* \{ */
 
 /*!
 Macro that defines a unary function <tt>bool F(AD<Base> x)</tt> 
@@ -249,6 +248,6 @@ inline bool AD<Base>::BinaryBool(
 	return FunName(x.value_, y.value_);
 }
 
-/* \} */
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
