@@ -1,19 +1,21 @@
-/* $Id: define.hpp 2234 2011-12-21 13:44:54Z bradbell $ */
+/* $Id: define.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_DEFINE_INCLUDED
 # define CPPAD_DEFINE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 /*!
+\defgroup define_hpp define.hpp
+\{
 \file define.hpp
 Define processor symbols and macros that are used by CppAD.
 */
@@ -31,17 +33,6 @@ in pod_vector.hpp.
 */
 # define CPPAD_OP_CODE_TYPE unsigned char
 
-/*!
-\def CPPAD_TAPE_ID_TYPE
-Is the type used to store tape identifies on the tape. If not size_t, then 
-<code>sizeof(CPPAD_TAPE_ID_TYPE) <= sizeof( size_t )</code>
-to conserve memory.
-This type must support \c std::numeric_limits,
-the \c <= operator,
-and conversion to \c size_t.
-*/
-# define CPPAD_TAPE_ID_TYPE unsigned int
-
 /*!
 \def CPPAD_USE_FORWARD0SWEEP
 If ture, use compute zero order sweeps using a specialized routine.
@@ -103,18 +94,6 @@ it is defined when cppad/local/define.hpp is included.
 # define CPPAD_NULL     0
 # endif
  
-/*!
-\def CPPAD_MAX_NUM_THREADS
-Specifies the maximum number of threads that CppAD can support.
-
-The user may define CPPAD_MAX_NUM_THREADS before including any of the CppAD
-header files.  If it is not yet defined,
-it is defined when cppad/local/define.hpp is included.
-*/
-# ifndef CPPAD_MAX_NUM_THREADS
-# define CPPAD_MAX_NUM_THREADS 48
-# endif
-
 /*!
 \def CPPAD_FOLD_ASSIGNMENT_OPERATOR(Op)
 Declares automatic coercion for certain AD assignment operations.
@@ -360,4 +339,5 @@ inline bool operator Op                                                \
 	(const VecAD_reference<double> &left, const double &right)        \
 {	return left.ADBase() Op AD<double>(right); }
 
+/*! \} */
 # endif
