@@ -1,12 +1,12 @@
-/* $Id: for_jac_sweep.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
+/* $Id: for_jac_sweep.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_FOR_JAC_SWEEP_INCLUDED
 # define CPPAD_FOR_JAC_SWEEP_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -16,6 +16,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup for_jac_sweep_hpp for_jac_sweep.hpp
+\{
 \file for_jac_sweep.hpp
 Compute Forward mode Jacobian sparsity patterns.
 */
@@ -39,7 +41,7 @@ using AD< \a Base > and computations by this routine are done using type
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param n
 is the number of independent variables on the tape.
@@ -626,6 +628,7 @@ void ForJacSweep(
 	return;
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 
 // preprocessor symbols that are local to this file
