@@ -1,13 +1,13 @@
-/* $Id: for_sparse_jac.hpp 2006 2011-07-12 17:35:39Z bradbell $ */
+/* $Id: for_sparse_jac.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_FOR_SPARSE_JAC_INCLUDED
 # define CPPAD_FOR_SPARSE_JAC_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -38,7 +38,7 @@ $icode%s% = %f%.ForSparseJac(%q%, %r%)%$$
 
 $head Purpose$$
 We use $latex F : B^n \rightarrow B^m$$ to denote the
-$xref/glossary/AD Function/AD function/$$ corresponding to $icode f$$.
+$cref/AD function/glossary/AD Function/$$ corresponding to $icode f$$.
 For a fixed $latex n \times q$$ matrix $latex R$$,
 the Jacobian of $latex F[ x + R * u ]$$
 with respect to $latex u$$ at $latex u = 0$$ is
@@ -46,7 +46,7 @@ $latex \[
 	S(x) = F^{(1)} ( x ) * R
 \] $$
 Given a
-$xref/glossary/Sparsity Pattern/sparsity pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
 for $latex R$$,
 $code ForSparseJac$$ returns a sparsity pattern for the $latex S(x)$$.
 
@@ -55,13 +55,13 @@ The object $icode f$$ has prototype
 $codei%
 	ADFun<%Base%> %f%
 %$$
-Note that the $xref/ADFun/$$ object $icode f$$ is not $code const$$.
+Note that the $cref ADFun$$ object $icode f$$ is not $code const$$.
 After a call to $code ForSparseJac$$, the sparsity pattern
 for each of the variables in the operation sequence
-is held in $icode f$$ (for possible later use by $cref/RevSparseHes/$$).
+is held in $icode f$$ (for possible later use by $cref RevSparseHes$$).
 These sparsity patterns are stored with elements of type $code bool$$
 or elements of type $code std::set<size_t>$$
-(see $xref/ForSparseJac/VectorSet/VectorSet/$$ below).
+(see $cref/VectorSet/ForSparseJac/VectorSet/$$ below).
  
 $subhead size_forward_bool$$
 After $code ForSparseJac$$, if $icode k$$ is a $code size_t$$ object, 
@@ -75,7 +75,7 @@ If the sparsity patterns for the previous $code ForSparseJac$$ used
 elements of type $code bool$$,
 the return value for $code size_forward_bool$$ will be non-zero.
 Otherwise, its return value will be zero.
-This sparsity pattern is stored for use by $cref/RevSparseHes/$$ and
+This sparsity pattern is stored for use by $cref RevSparseHes$$ and
 when it is not longer needed, it can be deleted 
 (and the corresponding memory freed) using 
 $codei%
@@ -94,7 +94,7 @@ If the sparsity patterns for this operation use elements of type $code bool$$,
 the return value for $code size_forward_set$$ will be zero.
 Otherwise, its return value will be non-zero
 (unless the entire sparsity pattern is false).
-This sparsity pattern is stored for use by $cref/RevSparseHes/$$ and
+This sparsity pattern is stored for use by $cref RevSparseHes$$ and
 when it is not longer needed, it can be deleted 
 (and the corresponding memory freed) using
 $codei%
@@ -105,7 +105,7 @@ After this call, $icode%f%.size_forward_set()%$$ will return zero.
 $head x$$
 the sparsity pattern is valid for all values of the independent 
 variables in $latex x \in B^n$$
-(even if it has $cref/CondExp/$$ or $cref/VecAD/$$ operations).
+(even if it has $cref CondExp$$ or $cref VecAD$$ operations).
 
 $head q$$
 The argument $icode q$$ has prototype
@@ -121,14 +121,14 @@ The argument $icode r$$ has prototype
 $codei%
 	const %VectorSet%& %r%
 %$$
-(see $xref/ForSparseJac/VectorSet/VectorSet/$$ below).
+(see $cref/VectorSet/ForSparseJac/VectorSet/$$ below).
 If it has elements of type $code bool$$,
 its size is $latex n * q$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $latex n$$ and all the set elements must be between
 zero and $icode%q%-1%$$ inclusive.
 It specifies a 
-$xref/glossary/Sparsity Pattern/sparsity pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
 for the matrix $icode R$$.
 
 $head s$$
@@ -136,19 +136,19 @@ The return value $icode s$$ has prototype
 $codei%
 	%VectorSet% %s%
 %$$
-(see $xref/ForSparseJac/VectorSet/VectorSet/$$ below).
+(see $cref/VectorSet/ForSparseJac/VectorSet/$$ below).
 If it has elements of type $code bool$$,
 its size is $latex m * q$$.
 If it has elements of type $code std::set<size_t>$$,
 its size is $latex m$$ and all its set elements are between
 zero and $icode%q%-1%$$ inclusive.
 It specifies a 
-$xref/glossary/Sparsity Pattern/sparsity pattern/$$ 
+$cref/sparsity pattern/glossary/Sparsity Pattern/$$ 
 for the matrix $latex S(x)$$.
 
 $head VectorSet$$
-The type $icode VectorSet$$ must be a $xref/SimpleVector/$$ class with
-$xref/SimpleVector/Elements of Specified Type/elements of type/$$
+The type $icode VectorSet$$ must be a $cref SimpleVector$$ class with
+$cref/elements of type/SimpleVector/Elements of Specified Type/$$
 $code bool$$ or $code std::set<size_t>$$;
 see $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for a discussion
 of the difference.
@@ -165,7 +165,7 @@ $children%
 	example/for_sparse_jac.cpp
 %$$
 The file
-$xref/ForSparseJac.cpp/$$
+$cref for_sparse_jac.cpp$$
 contains an example and test of this operation.
 It returns true if it succeeds and false otherwise.
 
@@ -177,12 +177,15 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup for_sparse_jac_hpp for_sparse_jac.hpp
+\{
 \file for_sparse_jac.hpp
 Forward mode Jacobian sparsity patterns.
 */
 
+// ---------------------------------------------------------------------------
 /*!
-Calculate Jacobian sparsity patterns using forward mode.
+Calculate Jacobian vector of bools sparsity patterns using forward mode.
 
 The C++ source code corresponding to this operation is
 \verbatim
@@ -195,9 +198,6 @@ is the base type for this recording.
 \tparam VectorSet
 is a simple vector class with elements of type \c bool.
 
-\tparam Sparsity
-is either \c sparse_pack or \c sparse_set. 
-
 \param q
 is the number of columns in the matrix \f$ R \f$.
 
@@ -238,7 +238,7 @@ and \a for_jac_sparsity.end() == \a q.
 It contains the forward sparsity pattern for all of the variables on the
 tape (given the sparsity pattern for the independent variables is \f$ R \f$).
 */
-template <class Base, class VectorSet, class Sparsity> 
+template <class Base, class VectorSet> 
 void ForSparseJacBool(
 	size_t                 q                , 
 	const VectorSet&       r                ,
@@ -247,28 +247,17 @@ void ForSparseJacBool(
 	CppAD::vector<size_t>& dep_taddr        ,
 	CppAD::vector<size_t>& ind_taddr        ,
 	CppAD::player<Base>&   play             ,
-	Sparsity&              for_jac_sparsity )
+	sparse_pack&           for_jac_sparsity )
 {
 	// temporary indices
 	size_t i, j;
 
-	// check VectorSet is Simple Vector class with bool elements
-	CheckSimpleVector<bool, VectorSet>();
-
 	// range and domain dimensions for F
 	size_t m = dep_taddr.size();
 	size_t n = ind_taddr.size();
 
-	CPPAD_ASSERT_KNOWN(
-		q > 0,
-		"ForSparseJac: q (first arugment) is not greater than zero"
-	);
-
-	CPPAD_ASSERT_KNOWN(
-		r.size() == n * q,
-		"ForSparseJac: r (second argument) length is not equal to\n"
-		"q (first argument) times domain dimension for ADFun object."
-	);
+	CPPAD_ASSERT_UNKNOWN(q > 0 );
+	CPPAD_ASSERT_UNKNOWN( size_t(r.size()) == n * q );
 
 	// allocate memory for the requested sparsity calculation
 	for_jac_sparsity.resize(total_num_var, q);
@@ -293,7 +282,7 @@ void ForSparseJacBool(
 	);
 
 	// return values corresponding to dependent variables
-	CPPAD_ASSERT_UNKNOWN( s.size() == m * q );
+	CPPAD_ASSERT_UNKNOWN( size_t(s.size()) == m * q );
 	for(i = 0; i < m; i++)
 	{	CPPAD_ASSERT_UNKNOWN( dep_taddr[i] < total_num_var );
 
@@ -311,7 +300,7 @@ void ForSparseJacBool(
 }
 
 /*!
-Calculate Jacobian sparsity patterns using forward mode.
+Calculate Jacobian vector of sets sparsity patterns using forward mode.
 
 The C++ source code corresponding to this operation is
 \verbatim
@@ -319,89 +308,57 @@ The C++ source code corresponding to this operation is
 \endverbatim
 
 \tparam Base
-is the base type for this recording.
+see \c SparseJacBool.
 
 \tparam VectorSet
-is a simple vector class with elements of the type \c std::set<size_t>.
-
-\tparam Sparsity
-is either \c sparse_pack or \c sparse_set. 
+is a simple vector class with elements of type \c std::set<size_t>.
 
 \param q
-is the number of columns in the matrix \f$ R \f$.
+see \c SparseJacBool.
 
 \param r
-is a sparsity pattern for the matrix \f$ R \f$.
+see \c SparseJacBool.
 
 \param s
-The input value of \a s must be a vector with size \c m
-where \c m is the number of dependent variables
-corresponding to the operation sequence stored in \a play. 
-On input, each element of \a s must be an empty set.
-On output, \a s is the sparsity pattern for the matrix
-\f[
-	S(x) = F^{(1)} (x) * R
-\f]
-where \f$ F \f$ is the function corresponding to the operation sequence
-and \a x is any argument value.
+see \c SparseJacBool.
 
 \param total_num_var
-is the total number of variable in this recording.
+see \c SparseJacBool.
 
 \param dep_taddr
-maps dependendent variable index
-to the corresponding variable in the tape.
+see \c SparseJacBool.
 
 \param ind_taddr
-maps independent variable index
-to the corresponding variable in the tape.
+see \c SparseJacBool.
 
 \param play
-is the recording that defines the function we are computing the sparsity 
-pattern for.
+see \c SparseJacBool.
 
 \param for_jac_sparsity
-the input value of \a for_jac_sparsity does not matter.
-On output, \a for_jac_sparsity.n_set() == \a total_num_var
-and \a for_jac_sparsity.end() == \a q.
-It contains the forward sparsity pattern for all of the variables on the
-tape (given the sparsity pattern for the independent variables is \f$ R \f$).
+see \c SparseJacBool.
 */
 
-template <class Base, class VectorSet, class Sparsity> 
+template <class Base, class VectorSet> 
 void ForSparseJacSet(
-	size_t                  q                , 
-	const VectorSet&        r                ,
-	VectorSet&              s                ,
-	size_t                  total_num_var    ,
-	CppAD::vector<size_t>&  dep_taddr        ,
-	CppAD::vector<size_t>&  ind_taddr        ,
-	CppAD::player<Base>&    play             ,
-	Sparsity&               for_jac_sparsity )
+	size_t                      q                , 
+	const VectorSet&            r                ,
+	VectorSet&                  s                ,
+	size_t                      total_num_var    ,
+	CppAD::vector<size_t>&      dep_taddr        ,
+	CppAD::vector<size_t>&      ind_taddr        ,
+	CppAD::player<Base>&        play             ,
+	CPPAD_INTERNAL_SPARSE_SET&  for_jac_sparsity )
 {
 	// temporary indices
 	size_t i, j;
 	std::set<size_t>::const_iterator itr;
 
-	// check VectorSet is Simple Vector class with sets for elements
-	CheckSimpleVector<std::set<size_t>, VectorSet>(
-		one_element_std_set<size_t>(), two_element_std_set<size_t>()
-	);
-
 	// range and domain dimensions for F
 	size_t m = dep_taddr.size();
 	size_t n = ind_taddr.size();
 
-	CPPAD_ASSERT_KNOWN(
-		q > 0,
-		"ForSparseJac: q (first arugment) is not greater than zero"
-	);
-
-	CPPAD_ASSERT_KNOWN(
-		r.size() == n,
-		"ForSparseJac: r (second argument) length is not equal to\n"
-		"the domain dimension for ADFun object."
-	);
+	CPPAD_ASSERT_UNKNOWN(q > 0 );
+	CPPAD_ASSERT_UNKNOWN( size_t(r.size()) == n );
 
 	// allocate memory for the requested sparsity calculation
 	for_jac_sparsity.resize(total_num_var, q);
@@ -434,7 +391,7 @@ void ForSparseJacSet(
 	);
 
 	// return values corresponding to dependent variables
-	CPPAD_ASSERT_UNKNOWN( s.size() == m );
+	CPPAD_ASSERT_UNKNOWN( size_t(s.size()) == m );
 	for(i = 0; i < m; i++)
 	{	CPPAD_ASSERT_UNKNOWN( dep_taddr[i] < total_num_var );
 		CPPAD_ASSERT_UNKNOWN( s[i].empty() );
@@ -450,7 +407,119 @@ void ForSparseJacSet(
 		}
 	}
 }
+// ---------------------------------------------------------------------------
+/*! 
+Private helper function for ForSparseJac(q, r).
 
+All of the description in the public member function ForSparseJac(q, r) 
+applies. 
+
+\param set_type
+is a \c bool value. This argument is used to dispatch to the proper source
+code depending on the value of \c VectorSet::value_type.
+
+\param q
+See \c ForSparseJac(q, r).
+
+\param r
+See \c ForSparseJac(q, r).
+
+\param s
+is the return value for the corresponding call to \c ForSparseJac(q, r).
+*/
+
+template <class Base>
+template <class VectorSet>
+void ADFun<Base>::ForSparseJacCase(
+	bool                set_type      ,
+	size_t              q             ,
+	const VectorSet&    r             ,
+	VectorSet&          s             )
+{	size_t m = Range();
+
+	// check VectorSet is Simple Vector class with bool elements
+	CheckSimpleVector<bool, VectorSet>();
+
+	// dimension size of result vector
+	s.resize( m * q );
+
+	CPPAD_ASSERT_KNOWN(
+		size_t(r.size()) == Domain() * q,
+		"ForSparseJac: using vectors of bools and r (second argument) length"
+		"\nis not equal to q (first argument) times domain dimension."
+	);
+
+	// store results in r and for_jac_sparse_pack_
+	ForSparseJacBool(
+		q                , 
+		r                ,
+		s                ,
+		total_num_var_   ,
+		dep_taddr_       ,
+		ind_taddr_       ,
+		play_            ,
+		for_jac_sparse_pack_ 
+	);
+}
+
+
+/*! 
+Private helper function for \c ForSparseJac(q, r).
+
+All of the description in the public member function \c ForSparseJac(q, r) 
+applies. 
+
+\param set_type
+is a \c std::set<size_t> object. 
+This argument is used to dispatch to the proper source
+code depending on the value of \c VectorSet::value_type.
+
+\param q
+See \c ForSparseJac(q, r).
+
+\param r
+See \c ForSparseJac(q, r).
+
+\param s
+is the return value for the corresponding call to \c ForSparseJac(q, r).
+*/
+template <class Base>
+template <class VectorSet>
+void ADFun<Base>::ForSparseJacCase(
+	const std::set<size_t>&    set_type      ,
+	size_t                     q             ,
+	const VectorSet&           r             ,
+	VectorSet&                 s             )
+{
+
+	// check VectorSet is Simple Vector class with sets for elements
+	CheckSimpleVector<std::set<size_t>, VectorSet>(
+		one_element_std_set<size_t>(), two_element_std_set<size_t>()
+	);
+
+	CPPAD_ASSERT_KNOWN(
+		size_t(r.size()) == Domain() ,
+		"ForSparseJac: using vectors of sets and r (second argument) length"
+		"\nis not equal to the domain dimension for ADFun object."
+	);
+
+	// dimension size of result vector
+	size_t m = Range();
+	s.resize( m );
+
+	// store results in r and for_jac_sparse_pack_
+	CppAD::ForSparseJacSet(
+		q                , 
+		r                ,
+		s                ,
+		total_num_var_   ,
+		dep_taddr_       ,
+		ind_taddr_       ,
+		play_            ,
+		for_jac_sparse_set_
+	);
+}
+// ---------------------------------------------------------------------------
 
 /*!
 User API for Jacobian sparsity patterns using forward mode.
@@ -520,6 +589,15 @@ VectorSet ADFun<Base>::ForSparseJac(
 {	VectorSet s;
 	typedef typename VectorSet::value_type Set_type; 
 
+	CPPAD_ASSERT_KNOWN(
+		q > 0,
+		"ForSparseJac: q (first arugment) is not greater than zero"
+	);
+
+	// free all memory currently in sparsity patterns
+	for_jac_sparse_pack_.resize(0, 0);
+	for_jac_sparse_set_.resize(0, 0);
+
 	ForSparseJacCase(
 		Set_type()  ,
 		q           ,
@@ -530,103 +608,7 @@ VectorSet ADFun<Base>::ForSparseJac(
 	return s;
 }
 
-/*! 
-Private helper function for ForSparseJac(q, r).
-
-All of the description in the public member function ForSparseJac(q, r) 
-applies. 
-
-\param set_type
-is a \c bool value. This argument is used to dispatch to the proper source
-code depending on the value of \c VectorSet::value_type.
-
-\param q
-See \c ForSparseJac(q, r).
-
-\param r
-See \c ForSparseJac(q, r).
-
-\param s
-is the return value for the corresponding call to \c ForSparseJac(q, r).
-*/
-
-template <class Base>
-template <class VectorSet>
-void ADFun<Base>::ForSparseJacCase(
-	bool                set_type      ,
-	size_t              q             ,
-	const VectorSet&    r             ,
-	VectorSet&          s             )
-{	size_t m = Range();
-
-	// dimension size of result vector
-	s.resize( m * q );
-
-	// free any results stored in for_jac_sparse_set_	
-	for_jac_sparse_set_.resize(0, 0);
-
-	// store results in r and for_jac_sparse_pack_
-	ForSparseJacBool(
-		q                , 
-		r                ,
-		s                ,
-		total_num_var_   ,
-		dep_taddr_       ,
-		ind_taddr_       ,
-		play_            ,
-		for_jac_sparse_pack_ 
-	);
-}
-
-
-/*! 
-Private helper function for \c ForSparseJac(q, r).
-
-All of the description in the public member function \c ForSparseJac(q, r) 
-applies. 
-
-\param set_type
-is a \c std::set<size_t> object. 
-This argument is used to dispatch to the proper source
-code depending on the value of \c VectorSet::value_type.
-
-\param q
-See \c ForSparseJac(q, r).
-
-\param r
-See \c ForSparseJac(q, r).
-
-\param s
-is the return value for the corresponding call to \c ForSparseJac(q, r).
-*/
-template <class Base>
-template <class VectorSet>
-void ADFun<Base>::ForSparseJacCase(
-	const std::set<size_t>&    set_type      ,
-	size_t                     q             ,
-	const VectorSet&           r             ,
-	VectorSet&                 s             )
-{	size_t m = Range();
-
-	// dimension size of result vector
-	s.resize( m );
-
-	// free any results stored in for_jac_sparse_set_	
-	for_jac_sparse_pack_.resize(0, 0);
-
-	// store results in r and for_jac_sparse_pack_
-	CppAD::ForSparseJacSet(
-		q                , 
-		r                ,
-		s                ,
-		total_num_var_   ,
-		dep_taddr_       ,
-		ind_taddr_       ,
-		play_            ,
-		for_jac_sparse_set_ 
-	);
-}
-
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
