@@ -1,13 +1,13 @@
-/* $Id: forward.hpp 2114 2011-10-14 18:59:16Z bradbell $ */
+/* $Id: forward.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_FORWARD_INCLUDED
 # define CPPAD_FORWARD_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -33,6 +33,8 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup forward_hpp forward.hpp
+\{
 \file forward.hpp
 User interface to forward mode computations
 */
@@ -77,7 +79,7 @@ Vector ADFun<Base>::Forward(
 	CheckSimpleVector<Base, Vector>();
 
 	CPPAD_ASSERT_KNOWN(
-		x_p.size() == n,
+		size_t(x_p.size()) == n,
 		"Second argument to Forward does not have length equal to\n"
 		"the dimension of the domain for the corresponding ADFun."
 	);
@@ -149,5 +151,6 @@ Vector ADFun<Base>::Forward(
 	return y_p;
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
