@@ -1,13 +1,13 @@
-/* $Id: identical.hpp 2091 2011-09-02 19:47:24Z bradbell $ */
+/* $Id: identical.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_IDENTICAL_INCLUDED
 # define CPPAD_IDENTICAL_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -17,6 +17,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup identical_hpp identical.hpp
+\{
 \file identical.hpp
 Check if certain properties is true for any possible AD tape play back.
 */
@@ -101,5 +103,6 @@ bool IdenticalEqualPar
 }
 // ==========================================================================
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
