@@ -1,13 +1,13 @@
-/* $Id: log_op.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: log_op.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_LOG_OP_INCLUDED
 # define CPPAD_LOG_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -15,6 +15,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup log_op_hpp log_op.hpp
+\{
 \file log_op.hpp
 Forward and reverse mode calculations for z = log(x).
 */
@@ -152,5 +154,6 @@ inline void reverse_log_op(
 	px[0] += pz[0] / x[0];
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
