@@ -1,21 +1,20 @@
-/* $Id: op.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
+/* $Id: op.hpp 2506 2012-10-24 19:36:49Z bradbell $ */
 # ifndef CPPAD_OP_INCLUDED
 # define CPPAD_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 // used by the sparse operators
-# include <cppad/local/sparse_pack.hpp>
-# include <cppad/local/sparse_set.hpp>
+# include <cppad/local/sparse_pattern.hpp>
 
 // operations
 # include <cppad/local/std_math_ad.hpp>
