@@ -1,13 +1,13 @@
-/* $Id: op_code.hpp 2240 2011-12-31 05:33:55Z bradbell $ */
+/* $Id: op_code.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_OP_CODE_INCLUDED
 # define CPPAD_OP_CODE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -24,6 +24,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*! 
+\defgroup op_code_hpp op_code.hpp
+\{
 \file op_code.hpp
 Defines the OpCode enum type and functions related to it.
 
@@ -88,13 +90,16 @@ enum OpCode {
 	SubvvOp,  //      variable   - variable
 	TanOp,    //  tan(variable)
 	TanhOp,   //  tan(variable)
-	// user atomic operation codes (note yet implemented)
+	// user atomic operation codes
 	UserOp,   //  start of a user atomic operaiton
 	UsrapOp,  //  this user atomic argument is a parameter
 	UsravOp,  //  this user atomic argument is a variable
 	UsrrpOp,  //  this user atomic result is a parameter
-	UsrrvOp   //  this user atomic result is a variable
+	UsrrvOp,  //  this user atomic result is a variable
+	NumberOp
 };
+// Note that bin/check_op_code.sh assumes the pattern '^\tNumberOp$' occurs
+// at the end of this list and only at the end of this list.
 
 /*!
 Table containing number of arguments for the corresponding operator.
@@ -169,7 +174,7 @@ Number of arguments corresponding to the specified operator.
 \param op 
 Operator for which we are fetching the number of arugments.
 
-- Check that \c UsrrvOp is the last defined operator.
+- Check that argument taple size equal to NumberOp
 - Check that \c CPPAD_OP_CODE_TYPE can support all the operator codes.
 - Check that \c op is a valid operator value.
 */
@@ -179,16 +184,16 @@ inline size_t NumArg( OpCode op)
 	// only do these checks once to save time
 	static bool first = true;
 	if( first )
-	{	CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) == 
-			sizeof(NumArgTable) / sizeof(NumArgTable[0]) - 1
+	{	CPPAD_ASSERT_UNKNOWN( size_t(NumberOp) ==
+			sizeof(NumArgTable) / sizeof(NumArgTable[0])
 		);
-		CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) <=
+		CPPAD_ASSERT_UNKNOWN( size_t(NumberOp) <=
 			std::numeric_limits<CPPAD_OP_CODE_TYPE>::max()
 		);
 		first = false;
 	}
 	// do this check every time
-	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(UsrrvOp) );
+	CPPAD_ASSERT_UNKNOWN( size_t(op) < size_t(NumberOp) );
 # endif
 
 	return NumArgTable[(size_t) op];
@@ -270,11 +275,11 @@ Operator for which we are fetching the number of result variables.
 */
 inline size_t NumRes(OpCode op)
 {	// check ensuring conversion to size_t is as expected
-	CPPAD_ASSERT_UNKNOWN( size_t(UsrrvOp) == 
-		sizeof(NumResTable) / sizeof(NumResTable[0]) - 2
+	CPPAD_ASSERT_UNKNOWN( size_t(NumberOp) == 
+		sizeof(NumResTable) / sizeof(NumResTable[0]) - 1
 	);
 	// this test ensures that all indices are within the table
-	CPPAD_ASSERT_UNKNOWN( size_t(op) <= size_t(UsrrvOp) );
+	CPPAD_ASSERT_UNKNOWN( size_t(op) < size_t(NumberOp) );
 
 	return NumResTable[(size_t) op];
 }
@@ -459,7 +464,7 @@ void printOp(
 		"Usrrv"
 	};
 	CPPAD_ASSERT_UNKNOWN( 
-		size_t(UsrrvOp) == sizeof(OpName) / sizeof(OpName[0]) - 1
+		size_t(NumberOp) == sizeof(OpName) / sizeof(OpName[0])
 	);
 
 	// print operator
@@ -672,5 +677,6 @@ void printOp(
 	std::cout << std::endl;
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
