@@ -1,13 +1,13 @@
-/* $Id: optimize.hpp 2233 2011-12-20 19:34:24Z bradbell $ */
+/* $Id: optimize.hpp 2683 2012-12-30 18:17:03Z bradbell $ */
 # ifndef CPPAD_OPTIMIZE_INCLUDED
 # define CPPAD_OPTIMIZE_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -59,9 +59,8 @@ derivatives using the original operation sequence.
 
 $subhead Testing$$
 You can run the CppAD $cref/speed/speed_main/$$ tests and see
-the corresponding changes in number of variables and execution time; see
-the speed tests in the install instructions
-$cref/Examples and Tests/InstallUnix/make/Examples and Tests/$$ list.
+the corresponding changes in number of variables and execution time; 
+see $cref cppad_test$$.
 
 $head Efficiency$$
 The $code optimize$$ member function
@@ -117,6 +116,8 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup optimize_hpp optimize.hpp
+\{
 \file optimize.hpp
 Routines for optimizing a tape
 */
@@ -1161,7 +1162,7 @@ void optimize(
 	// -------------------------------------------------------------
 
 	// Erase all information in the recording
-	rec->Erase();
+	rec->free();
 
 	// Initilaize table mapping hash code to variable index in tape
 	// as pointing to the BeginOp at the beginning of the tape
@@ -1685,8 +1686,9 @@ void ADFun<Base>::optimize(void)
 		{	CPPAD_ASSERT_UNKNOWN( dep_taddr_[i] < total_num_var_ );
 			y[i] = taylor_[ dep_taddr_[i] * taylor_col_dim_ + 0];
 		}
-		// maximum zero order coefficient
-		for(i = 0; i < total_num_var_; i++)
+		// maximum zero order coefficient not counting BeginOp at beginning
+		// (which is correpsonds to uninitialized memory).
+		for(i = 1; i < total_num_var_; i++)
 		{	if(  abs_geq(taylor_[i*taylor_col_dim_+0] , max_taylor) )
 				max_taylor = taylor_[i*taylor_col_dim_+0];
 		}
@@ -1696,19 +1698,19 @@ void ADFun<Base>::optimize(void)
 	// create the optimized recording
 	CppAD::optimize<Base>(n, dep_taddr_, &play_, &rec);
 
-	// now replace the recording
-	play_ = rec;
-
 	// number of variables in the recording
 	total_num_var_ = rec.num_rec_var();
 
+	// now replace the recording
+	play_.get(rec);
+
 	// free memory allocated for sparse Jacobian calculation
 	// (the results are no longer valid)
 	for_jac_sparse_pack_.resize(0, 0);
 	for_jac_sparse_set_.resize(0,0);
 
 	// free old Taylor coefficient memory
-	taylor_.erase();
+	taylor_.free();
 	taylor_per_var_ = 0;
 	taylor_col_dim_ = 0;
 
@@ -1732,5 +1734,6 @@ void ADFun<Base>::optimize(void)
 # endif
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
