@@ -1,13 +1,13 @@
-/* $Id: ordered.hpp 2091 2011-09-02 19:47:24Z bradbell $ */
+/* $Id: ordered.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_ORDERED_INCLUDED
 # define CPPAD_ORDERED_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -18,6 +18,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 CPPAD_BEGIN_NAMESPACE
 
 /*!
+\defgroup ordered_hpp ordered.hpp
+\{
 \file ordered.hpp
 Check and AD values ordering properties relative to zero.
 */
@@ -97,6 +99,7 @@ CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
 bool abs_geq(const AD<Base>& x, const AD<Base>& y)
 {	return abs_geq(x.value_, y.value_); }
 // ============================================================================
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
 
