@@ -1,13 +1,13 @@
-/* $Id: player.hpp 1986 2011-06-18 20:33:17Z bradbell $ */
+/* $Id: player.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_PLAYER_INCLUDED
 # define CPPAD_PLAYER_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -15,6 +15,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup player_hpp player.hpp
+\{
 \file player.hpp
 File used to define the player class.
 */
@@ -77,28 +79,31 @@ public:
  	Moving an operation sequence from a recorder to a player
  
 	\param rec
-	the object that was used to record the operation sequence.
+	the object that was used to record the operation sequence.  After this 
+	operation, the state of the recording is no longer defined. For example,
+	the \c pod_vector member variables in \c this have been swapped with
+	\c rec .
  	*/
-	void operator=(const recorder<Base> &rec)
+	void get(recorder<Base>& rec)
 	{	size_t i;
 
 		// Var
 		num_rec_var_        = rec.num_rec_var_;
 
 		// Op
-		rec_op_             = rec.rec_op_;
+		rec_op_.swap(rec.rec_op_);
 
 		// VecInd
-		rec_vecad_ind_      = rec.rec_vecad_ind_;
+		rec_vecad_ind_.swap(rec.rec_vecad_ind_);
 
 		// Arg
-		rec_op_arg_         = rec.rec_op_arg_;
+		rec_op_arg_.swap(rec.rec_op_arg_);
 
 		// Par
-		rec_par_            = rec.rec_par_;
+		rec_par_.swap(rec.rec_par_);
 
 		// Txt
-		rec_text_           = rec.rec_text_;
+		rec_text_.swap(rec.rec_text_);
 
 		// set the number of VecAD vectors
 		num_rec_vecad_vec_ = 0;
@@ -572,5 +577,6 @@ public:
 
 };
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
