@@ -1,13 +1,13 @@
-/* $Id: prototype_op.hpp 2178 2011-10-30 06:52:58Z bradbell $ */
+/* $Id: prototype_op.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_PROTOTYPE_OP_INCLUDED
 # define CPPAD_PROTOTYPE_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -16,6 +16,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup prototype_op_hpp prototype_op.hpp
+\{
 \file prototype_op.hpp
 Documentation for generic cases (these generic cases are never used).
 */
@@ -1042,7 +1044,7 @@ where v is a VecAD<Base> vector and x is an AD<Base> index.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param op
 is the code corresponding to this operator; i.e., LdpOp or LdvOp
@@ -1229,7 +1231,7 @@ where i_vec is defined under the heading \a arg[1] below:
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 
 \param op
@@ -1310,7 +1312,7 @@ and it uses them to compute the sparsity patterns for
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param i_z
 variable index corresponding to the result for this operation; 
@@ -1376,7 +1378,7 @@ and it uses them to compute the sparsity patterns for the Hessian of
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param i_z
 variable index corresponding to the result for this operation; 
@@ -1554,7 +1556,7 @@ where Rel is one of the following: Lt, Le, Eq, Ge, Gt.
 
 \tparam Vector_set
 is the type used for vectors of sets. It can be either
-\c sparse_pack or \c sparse_set.
+\c sparse_pack, \c sparse_set, or \c sparse_list.
 
 \param i_z
 is the AD variable index corresponding to the variable z.
@@ -1621,5 +1623,6 @@ inline void sparse_conditional_exp_op(
 	CPPAD_ASSERT_UNKNOWN( false );
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
