@@ -1,13 +1,13 @@
-/* $Id: sqrt_op.hpp 1641 2010-02-01 16:39:45Z bradbell $ */
+/* $Id: sqrt_op.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_SQRT_OP_INCLUDED
 # define CPPAD_SQRT_OP_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -16,6 +16,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup sqrt_op_hpp sqrt_op.hpp
+\{
 \file sqrt_op.hpp
 Forward and reverse mode calculations for z = sqrt(x).
 */
@@ -54,6 +56,10 @@ inline void forward_sqrt_op(
 		z[j] = sqrt( x[0] );
 	else
 	{
+		CPPAD_ASSERT_KNOWN(
+			x[0] != Base(0),
+			"Forward: attempt to take derivatve of square root of zero"
+		)
 		z[j] = Base(0);
 		for(k = 1; k < j; k++)
 			z[j] -= Base(k) * z[k] * z[j-k];
@@ -127,11 +133,18 @@ inline void reverse_sqrt_op(
 	const Base* z  = taylor  + i_z * nc_taylor;
 	Base* pz       = partial + i_z * nc_partial;
 
+	CPPAD_ASSERT_KNOWN(
+		z[0] != Base(0),
+		"Reverse: attempt to take derivatve of square root of zero"
+	)
+
 	// number of indices to access
 	size_t j = d;
 	size_t k;
 	while(j)
-	{	// scale partial w.r.t. z[j]
+	{
+
+		// scale partial w.r.t. z[j]
 		pz[j]   /= z[0];
 
 		pz[0]   -= pz[j] * z[j];
@@ -143,5 +156,6 @@ inline void reverse_sqrt_op(
 	px[0] += pz[0] / (Base(2) * z[0]);
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
