@@ -1,13 +1,13 @@
-// $Id: std_set.hpp 2082 2011-08-31 17:50:58Z bradbell $
+// $Id: std_set.hpp 2625 2012-12-23 14:34:12Z bradbell $
 # ifndef CPPAD_STD_SET_INCLUDED
 # define CPPAD_STD_SET_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -20,6 +20,8 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup std_set_hpp std_set.hpp
+\{
 \file std_set.hpp
 Two constant standard sets (currently used for concept checking).
 */
@@ -49,5 +51,6 @@ const std::set<Scalar>& two_element_std_set(void)
 	return two;
 }  
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
