@@ -1,13 +1,13 @@
-/* $Id: user_atomic.hpp 2210 2011-11-24 21:56:53Z bradbell $ */
+/* $Id: user_atomic.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_USER_ATOMIC_INCLUDED
 # define CPPAD_USER_ATOMIC_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -75,7 +75,7 @@ of a function
 $latex \[
 	y = f(x) \; {\rm where} \; f : B^n \rightarrow B^m 
 \] $$
-more efficiently than by coding it $codei%AD<%Base%>%$$ 
+more efficiently than by coding it using $codei%AD<%Base%>%$$ 
 $cref/atomic/glossary/Operation/Atomic/$$ operations
 and letting CppAD do the rest.
 In this case, $code CPPAD_USER_ATOMIC$$ can be used
@@ -93,7 +93,7 @@ must be defined by the user.
 The $icode forward$$ the routine, 
 for the case $icode%k% = 0%$$, must be implemented.
 Functions with the correct prototype,
-that just return $icode false$$, 
+that just return $code false$$, 
 can be used for the other cases 
 (unless they are required by your calculations). 
 For example, you need not implement
@@ -275,6 +275,9 @@ $codei%
 	%afun%(%id%, %ax%, %ay%)
 %$$
 must not be in $cref/parallel/ta_in_parallel/$$ mode.
+In addition, the
+$cref/user_atomic clear/user_atomic/clear/$$
+routine cannot be called while in parallel mode.
 
 $head forward$$
 The macro argument $icode forward$$ is a
@@ -297,7 +300,16 @@ y_i^0 & = & Y(0)
 \\
 y_i^1 & = & Y^{(1)} ( 0 ) 
         = f_i^{(1)} ( x^0 ) X^{(1)} ( 0 ) 
-        =  f_i^{(1)} ( x^0 ) x^1 
+        = f_i^{(1)} ( x^0 ) x^1 
+\\
+y_i^2 
+& = & \frac{1}{2 !} Y^{(2)} (0)
+\\
+& = & \frac{1}{2} X^{(1)} (0)^\R{T} f_i^{(2)} ( x^0 ) X^{(1)} ( 0 )
+  +   \frac{1}{2} f_i^{(1)} ( x^0 ) X^{(2)} ( 0 )
+\\
+& = & \frac{1}{2} (x^1)^\R{T} f_i^{(2)} ( x^0 ) x^1 
+  +    f_i^{(1)} ( x^0 ) x^2
 \end{array}
 \] $$
 Then, for $latex i = 0 , \ldots , m-1$$, it sets
@@ -415,24 +427,26 @@ $codei%
 and $icode%px%.size() >= (%k% + 1) * %n%$$.
 The input values of the elements of $icode px$$ do not matter.
 Upon return,
-for $latex j = 0 , \ldots , n-1$$ and $latex \ell = 0 , \ldots , k$$,
+for $latex j = 0 , \ldots , n-1$$ and $latex p = 0 , \ldots , k$$,
 $latex \[
 \begin{array}{rcl}
-px [ j * (k + 1) + \ell ] & = & \partial H / \partial x_j^\ell
+px [ j * (k + 1) + p ] & = & \partial H / \partial x_j^p
 \\
 & = & 
 ( \partial G / \partial \{ y_i^\ell \} ) 
-	( \partial \{ y_i^\ell \} / \partial x_j^\ell )
+	( \partial \{ y_i^\ell \} / \partial x_j^p )
 \\
 & = & 
 \sum_{i=0}^{m-1} \sum_{\ell=0}^k
-( \partial G / \partial y_i^\ell ) ( \partial y_i^\ell / \partial x_j^\ell )
+( \partial G / \partial y_i^\ell ) ( \partial y_i^\ell / \partial x_j^p )
 \\
 & = & 
-\sum_{i=0}^{m-1} \sum_{\ell=0}^k
-py[ i * (k + 1 ) + \ell ] ( \partial F_i^\ell / \partial x_j^\ell )
+\sum_{i=0}^{m-1} \sum_{\ell=p}^k
+py[ i * (k + 1 ) + \ell ] ( \partial F_i^\ell / \partial x_j^p )
 \end{array}
 \] $$
+Note that we have used the fact that for $latex \ell < p$$,
+$latex \partial F_i^\ell / \partial x_j^p = 0$$.
 If $icode%px%.size() > (%k% + 1) * %n%$$,
 the other components of $icode px$$ are not specified and should not be used.
 
@@ -452,7 +466,7 @@ Given a $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for $latex R$$,
 $icode for_jac_sparse$$ computes a sparsity pattern for $latex S(x)$$.
 
 $subhead Usage$$
-This routine is used by calls to $cref/ForSparseJac/$$.
+This routine is used by calls to $cref ForSparseJac$$.
 
 $subhead q$$
 The $icode for_jac_sparse$$ argument $icode q$$ has prototype
@@ -502,8 +516,8 @@ Given a $cref/sparsity pattern/glossary/Sparsity Pattern/$$ for $latex S$$,
 $icode rev_jac_sparse$$ computes a sparsity pattern for $latex R(x)$$.
 
 $subhead Usage$$
-This routine is used by calls to $cref/RevSparseJac/$$
-and to $cref/optimize/$$.
+This routine is used by calls to $cref RevSparseJac$$
+and to $cref optimize$$.
 
 
 $subhead q$$
@@ -522,9 +536,9 @@ $codei%
 %$$
 and $icode%s%.size() >= %m%$$.
 For $latex i = 0 , \ldots , m-1$$, 
-all the elements of $icode%s%[%i%}%$$
+all the elements of $icode%s%[%i%]%$$
 are between zero and $icode%q%-1%$$ inclusive.
-This specifies a sparsity pattern for the matrix $latex S^\T$$.
+This specifies a sparsity pattern for the matrix $latex S^\R{T}$$.
 
 $subhead r$$
 The $icode rev_jac_sparse$$ return value $icode r$$ has prototype
@@ -536,7 +550,7 @@ The input values of its sets do not matter.
 Upon return for $latex j = 0 , \ldots , n-1$$,
 all the elements of $icode%r%[%j%]%$$
 are between zero and $icode%q%-1%$$ inclusive.
-This represents a sparsity pattern for the matrix $latex R(x)^\T$$.
+This represents a sparsity pattern for the matrix $latex R(x)^\R{T}$$.
 
 $head rev_hes_sparse$$
 The macro argument $icode rev_hes_sparse$$
@@ -554,7 +568,7 @@ $latex \[
 \] $$
 
 $subhead Usage$$
-This routine is used by calls to $cref/RevSparseHes/$$.
+This routine is used by calls to $cref RevSparseHes$$.
 
 $subhead q$$
 The $icode rev_hes_sparse$$ argument $icode q$$ has prototype
@@ -577,7 +591,7 @@ This specifies a sparsity pattern for the matrix $latex R \in B^{n \times q}$$.
 $subhead s$$
 The $icode rev_hes_sparse$$ argument $icode s$$ has prototype
 $codei%
-     const CppAD::vector<bool> >& %s%
+     const CppAD::vector<bool>& %s%
 %$$
 and $icode%s%.size() >= %m%$$.
 This specifies a sparsity pattern for the matrix 
@@ -586,12 +600,15 @@ $latex S(x) = g^{(1)} (y) \in B^{1 \times m}$$.
 $subhead t$$
 The $icode rev_hes_sparse$$ argument $icode t$$ has prototype
 $codei%
-     CppAD::vector<bool> >& %t%
+     CppAD::vector<bool>& %t%
 %$$
 and $icode%t%.size() >= %n%$$.
 The input values of its elements do not matter.
 Upon return it represents a sparsity pattern for the matrix 
-$latex T(x) = (g \circ f)^{(1)} (x) \in B^{1 \times n}$$.
+$latex T(x) \in B^{1 \times n}$$ defined by
+$latex \[
+T(x)  =  (g \circ f)^{(1)} (x) =  S(x) * f^{(1)} (x)
+\] $$
 
 $subhead u$$
 The $icode rev_hes_sparse$$ argument $icode u$$ has prototype
@@ -641,6 +658,16 @@ V(x)
 \\
 & = &
 (g \circ f)^{(2)}( x ) R
+\\
+& = &
+f^{(1)} (x)^\R{T} g^{(2)} ( y ) f^{(1)} (x)  R
++
+\sum_{i=1}^m [ g^{(1)} (y) ]_i \; f_i^{(2)} (x) R
+\\
+& = &
+f^{(1)} (x)^\R{T} U(x)
++
+\sum_{i=1}^m S(x)_i \; f_i^{(2)} (x) R
 \end{array}
 \] $$
 
@@ -655,18 +682,27 @@ for other uses by the same thread.
 This should be called when you are done using the 
 user atomic functions for a specific value of $icode Base$$.
 
+$subhead Restriction$$
+The user atomic $code clear$$ routine cannot be called
+while in $cref/parallel/ta_in_parallel/$$ execution mode.
+
 $children%
+	example/reciprocal.cpp%
 	example/user_tan.cpp%
 	example/mat_mul.cpp
 %$$
 $head Example$$
 
+$subhead Reciprocal$$
+The file $cref reciprocal.cpp$$ contains the simplest example and test
+of a user atomic operation.
+
 $subhead Tangent Function$$
-The file $cref/user_tan.cpp/$$ contains an example and test
+The file $cref user_tan.cpp$$ contains an example and test
 implementation of the tangent function as a user atomic operation.
 
 $subhead Matrix Multiplication$$
-The file  $cref/mat_mul.cpp/$$ contains an example and test
+The file  $cref mat_mul.cpp$$ contains an example and test
 implementation of matrix multiplication a a user atomic operation.
 
 $end
@@ -680,6 +716,8 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup user_atomic_hpp user_atomic.hpp
+\{
 \file user_atomic.hpp
 user defined atomic operations.
 */
@@ -832,10 +870,10 @@ private:
 
 	/// temporary work space used to avoid memory allocation/deallocation
 	/// extra information to be passed to the functions
-	vector<bool>            vx_;
-	vector<bool>            vy_;
-	vector<Base>             x_;
-	vector<Base>             y_;
+	vector<bool>            vx_[CPPAD_MAX_NUM_THREADS];
+	vector<bool>            vy_[CPPAD_MAX_NUM_THREADS];
+	vector<Base>             x_[CPPAD_MAX_NUM_THREADS];
+	vector<Base>             y_[CPPAD_MAX_NUM_THREADS];
 
 	/// List of all objects in this class.
 	static std::vector<user_atomic *>& List(void)
@@ -914,35 +952,41 @@ public:
 	{	size_t i, j, k;
 		size_t n = ax.size();
 		size_t m = ay.size();
+		size_t thread = thread_alloc::thread_num();
 # ifndef NDEBUG
 		bool ok;
 		std::string msg = "user_atomoc: ";
 # endif
+		vector <Base>& x  = x_[thread];
+		vector <Base>& y  = y_[thread];
+		vector <bool>& vx = vx_[thread];
+		vector <bool>& vy = vy_[thread];
 		//
-		if( x_.size() < n )
-		{	x_.resize(n);
-			vx_.resize(n);
+		if( x.size() < n )
+		{	x.resize(n);
+			vx.resize(n);
 		}
-		if( y_.size() < m )
-		{	y_.resize(m);
-			vy_.resize(m);
+		if( y.size() < m )
+		{	y.resize(m);
+			vy.resize(m);
 		}
 		// 
 		// Determine if we are going to have to tape this operation
-		size_t tape_id     = 0;
+		tape_id_t tape_id     = 0;
 		ADTape<Base>* tape = CPPAD_NULL;
 		for(j = 0; j < n; j++)
-		{	x_[j]   = ax[j].value_;
-			vx_[j]  = Variable( ax[j] );
-			if ( (tape == CPPAD_NULL) & vx_[j] )
+		{	x[j]   = ax[j].value_;
+			vx[j]  = Variable( ax[j] );
+			if ( (tape == CPPAD_NULL) & vx[j] )
 			{	tape    = ax[j].tape_this();
-				tape_id = ax[j].id_;
+				tape_id = ax[j].tape_id_;
 			}
 # ifndef NDEBUG
-			ok = (tape_id == 0) | Parameter(ax[j]) | (tape_id == ax[j].id_);
+			ok  = (tape_id == 0) | Parameter(ax[j]);
+			ok |= (tape_id == ax[j].tape_id_);
 			if( ! ok )
 			{	msg = msg + name_ + 
-				": ax contains variables from different OpenMP threads.";
+				": ax contains variables from different threads.";
 				CPPAD_ASSERT_KNOWN(false, msg.c_str());
 			}
 # endif
@@ -950,9 +994,9 @@ public:
 		// Use zero order forward mode to compute values
 		k  = 0;
 # if NDEBUG
-		f_(id, k, n, m, vx_, vy_, x_, y_);  
+		f_(id, k, n, m, vx, vy, x, y);  
 # else
-		ok = f_(id, k, n, m, vx_, vy_, x_, y_);  
+		ok = f_(id, k, n, m, vx, vy, x, y);  
 		if( ! ok )
 		{	msg = msg + name_ + ": ok returned false from "
 				"zero order forward mode calculation.";
@@ -961,11 +1005,11 @@ public:
 # endif
 		// pass back values
 		for(i = 0; i < m; i++)
-		{	ay[i].value_ = y_[i];
+		{	ay[i].value_ = y[i];
 
 			// initialize entire vector as a constant (not on tape)
-			ay[i].id_    = CPPAD_MAX_NUM_THREADS;
-			ay[i].taddr_ = 0;
+			ay[i].tape_id_ = 0;
+			ay[i].taddr_   = 0;
 		}
 		// if tape is not null, ay is on the tape
 		if( tape != CPPAD_NULL )
@@ -986,7 +1030,7 @@ public:
 			CPPAD_ASSERT_UNKNOWN( NumArg(UsravOp) == 1 );
 			CPPAD_ASSERT_UNKNOWN( NumArg(UsrapOp) == 1 );
 			for(j = 0; j < n; j++)
-			{	if( vx_[j] )
+			{	if( vx[j] )
 				{	// information for an argument that is a variable
 					tape->Rec_.PutArg(ax[j].taddr_);
 					tape->Rec_.PutOp(UsravOp);
@@ -1005,9 +1049,9 @@ public:
 			CPPAD_ASSERT_UNKNOWN( NumArg(UsrrvOp) == 0 );
 			CPPAD_ASSERT_UNKNOWN( NumRes(UsrrvOp) == 1 );
 			for(i = 0; i < m; i++)
-			{	if( vy_[i] )
-				{	ay[i].taddr_ = tape->Rec_.PutOp(UsrrvOp);
-					ay[i].id_    = tape_id;
+			{	if( vy[i] )
+				{	ay[i].taddr_    = tape->Rec_.PutOp(UsrrvOp);
+					ay[i].tape_id_  = tape_id;
 				}
 				else
 				{	addr_t p = tape->Rec_.PutPar(ay[i].value_);
@@ -1314,17 +1358,26 @@ public:
 
 	/// Free static CppAD::vector memory used by this class (work space)
 	static void clear(void)
-	{	size_t i = List().size();
+	{	CPPAD_ASSERT_KNOWN(
+			! thread_alloc::in_parallel() ,
+			"cannot use user_atomic clear during parallel execution"
+		);
+		size_t i = List().size();
 		while(i--)
-		{	user_atomic* op = List()[i];
-			op->vx_.resize(0);
-			op->vy_.resize(0);
-			op->x_.resize(0);
-			op->y_.resize(0);
+		{	size_t thread = CPPAD_MAX_NUM_THREADS;
+			while(thread--)
+			{
+				user_atomic* op = List()[i];
+				op->vx_[thread].clear();
+				op->vy_[thread].clear();
+				op->x_[thread].clear();
+				op->y_[thread].clear();
+			}
 		}
 		return;
 	}
 };
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
