@@ -1,13 +1,13 @@
-/* $Id: nan.hpp 2085 2011-09-01 14:54:04Z bradbell $ */
+/* $Id: nan.hpp 2906 2013-10-06 13:51:24Z bradbell $ */
 # ifndef CPPAD_NAN_INCLUDED
 # define CPPAD_NAN_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-13 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -102,7 +102,7 @@ It is true if the value $icode s$$ is $code nan$$.
 
 $head hasnan$$
 This routine determines if a 
-$cref/SimpleVector/$$ has an element that is $code nan$$.
+$cref SimpleVector$$ has an element that is $code nan$$.
 
 $subhead v$$
 The argument $icode v$$ has prototype
@@ -131,18 +131,19 @@ $rnext
 $icode%a% != %b%$$ $cnext
 	not equality operator (returns a $code bool$$ object)
 $tend
-Note that the division operator will be used with $icode a$$ and $italic b$$
+Note that the division operator will be used with $icode a$$ and $icode b$$
 equal to zero. For some types (e.g. $code int$$) this may generate
 an exception. No attempt is made to catch any such exception.
 
 $head Vector$$
-The type $icode Vector$$ must be a $cref/SimpleVector/$$ class with
+The type $icode Vector$$ must be a $cref SimpleVector$$ class with
 elements of type $icode Scalar$$.
 
 $head Parallel Mode$$
 $index parallel, user_atomic$$
 $index user_atomic, parallel$$
-For each type $icode Scalar$$,
+The function $code isnan$$ uses static variables.
+Hence for each type $icode Scalar$$,
 the first call to
 $codei%
 	%b% = isnan(%s%)
@@ -150,11 +151,17 @@ $codei%
 must not be $cref/parallel/ta_in_parallel/$$ execution mode; 
 see $code isnan$$ in $cref/parallel_ad/parallel_ad/isnan/$$.
 
+$head Memory Allocation$$
+This function is called by CppAD even if it is not
+explicitly referenced by the users code.
+Hence any corresponding memory allocation for a static value
+of type $icode Scalar$$ my be preformed.
+
 $children%
 	example/nan.cpp
 %$$
 $head Example$$
-The file $cref/nan.cpp/$$
+The file $cref nan.cpp$$
 contains an example and test of this routine.
 It returns true if it succeeds and false otherwise.
 
@@ -191,8 +198,6 @@ inline bool isnan(const Scalar &s)
 template <class Vector>
 bool hasnan(const Vector &v)
 {
-	typedef typename Vector::value_type Scalar;
-
 	bool found_nan;
 	size_t i;
 	i   = v.size();
