@@ -1,13 +1,13 @@
-/* $Id: vector.hpp 2085 2011-09-01 14:54:04Z bradbell $ */
+/* $Id: vector.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_VECTOR_INCLUDED
 # define CPPAD_VECTOR_INCLUDED
 
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -42,7 +42,7 @@ $code # include <cppad/vector.hpp>$$
 $head Description$$
 The include file $code cppad/vector.hpp$$ defines the
 vector template class $code CppAD::vector$$.
-This is a $xref/SimpleVector/$$ template class and in addition
+This is a $cref SimpleVector$$ template class and in addition
 it has the features listed below:
 
 $head Include$$
@@ -71,20 +71,24 @@ $codei%
 	%y% = %x%
 %$$
 has all the properties listed for a
-$xref/SimpleVector/Assignment/simple vector assignment/$$
+$cref/simple vector assignment/SimpleVector/Assignment/$$
 plus the following:
-$pre
 
-$$
+$subhead Check Size$$
 The $code CppAD::vector$$ template class will check that
-the size of $icode x$$ is equal to the size of $icode y$$
+the size of $icode x$$ is either zero or the size of $icode y$$
 before doing the assignment.
-If the sizes are not equal, $code CppAD::vector$$ will use
-$xref/ErrorHandler/$$
+If this is not the case, $code CppAD::vector$$ will use
+$cref ErrorHandler$$
 to generate an appropriate error report.
-$pre
+Allowing for assignment to a vector with size zero makes the following
+code work:
+$codei%
+	CppAD::vector<%Scalar%> %y%;
+	%y% = %x%;
+%$$
 
-$$
+$subhead Return Reference$$
 A reference to the vector $icode y$$ is returned.
 An example use of this reference is in multiple assignments of the form
 $codei%
@@ -100,19 +104,19 @@ $codei%
 	%x%[%i%]
 %$$
 has all the properties listed for a
-$xref/SimpleVector/Element Access/simple vector element access/$$
+$cref/simple vector element access/SimpleVector/Element Access/$$
 plus the following:
 $pre
 
 $$
-The object $codei%%x%[%i%]%$$ has type $icode Scalar$$
+The object $icode%x%[%i%]%$$ has type $icode Scalar$$
 (is not possibly a different type that can be converted to $icode Scalar$$).
 $pre
 
 $$
 If $icode i$$ is not less than the size of the $icode x$$,
 $code CppAD::vector$$ will use
-$xref/ErrorHandler/$$
+$cref ErrorHandler$$
 to generate an appropriate error report.
 
 $head push_back$$
@@ -125,7 +129,7 @@ $codei%
 	%x%.push_back(%s%)
 %$$
 extends the vector $icode x$$ so that its new size is $icode n$$ plus one
-and $codei%%x%[%n%]%$$ is equal to $icode s$$
+and $icode%x%[%n%]%$$ is equal to $icode s$$
 (equal in the sense of the $icode Scalar$$ assignment operator).
 
 
@@ -166,8 +170,14 @@ will output the value $icode e$$ to the standard
 output stream $icode os$$.
 
 $head resize$$
-If the $code resize$$ member function is called with argument
-value zero, all memory allocated for the vector will be freed.
+The call $icode%x%.resize(%n%)%$$ set the size of $icode x$$ equal to 
+$icode n$$. 
+If $icode%n% <= %x%.capacity()%$$, 
+no memory is freed or allocated and the capacity of $icode x$$ does not change.
+
+$head clear$$
+All memory allocated for the vector is freed
+and both its size and capacity are set to zero.
 The can be useful when using very large vectors
 and when checking for memory leaks (and there are global vectors)
 see the $cref/memory/CppAD_vector/Memory and Parallel Mode/$$ discussion.
@@ -196,7 +206,7 @@ surrounding $code {$$, $code }$$ and with no separating commas or spaces.
 $lnext
 If $icode x$$ has type $code vectorBool$$
 and $icode i$$ has type $code size_t$$,
-the element access value $codei%%x%[%i%]%$$ has an unspecified type
+the element access value $icode%x%[%i%]%$$ has an unspecified type
 (referred to here as $icode elementType$$)
 that can be implicitly converted to $code bool$$.
 The return value of the assignment operator
@@ -214,7 +224,8 @@ $lend
 $head Memory and Parallel Mode$$
 $index thread_alloc, vector$$
 $index vector, thread_alloc$$
-These vectors use the OpenMP fast memory allocator $cref/thread_alloc/$$:
+These vectors use the multi-threaded fast memory allocator 
+$cref thread_alloc$$:
 
 $list number$$
 The routine $cref/parallel_setup/ta_parallel_setup/$$ must
@@ -238,8 +249,8 @@ $children%
 	example/vector_bool.cpp
 %$$
 The files
-$xref/CppAD_vector.cpp/$$ and
-$xref/vectorBool.cpp/$$ each
+$cref cppad_vector.cpp$$ and
+$cref vector_bool.cpp$$ each
 contain an example and test of this template class.
 They return true if they succeed and false otherwise.
 
@@ -271,6 +282,8 @@ $end
 
 CPPAD_BEGIN_NAMESPACE
 /*!
+\defgroup vector_hpp vector.hpp
+\{
 \file vector.hpp
 File used to define CppAD::vector and CppAD::vectorBool
 */
@@ -338,31 +351,39 @@ public:
 
 	/// change the number of elements in this vector.
 	inline void resize(
-		/// new number of elements for this vector, if zero
-		/// make sure the memory is returned to thread_alloc.
+		/// new number of elements for this vector
 		size_t n
 	)
 	{	length_ = n;
 		// check if we can use current memory
-		if( (capacity_ >= length_) & (length_ > 0)  )
+		if( capacity_ >= length_ )
 			return;
 		// check if there is old memory to be freed
 		if( capacity_ > 0 )
 			thread_alloc::delete_array(data_);
-		// check if we need new memory 
-		if( length_ == 0 )
-			capacity_ = 0;
-		else
-		{	// get new memory and set capacity
-			data_ = thread_alloc::create_array<Type>(length_, capacity_);
-		}
+		// get new memory and set capacity
+		data_ = thread_alloc::create_array<Type>(length_, capacity_);
 	}
+
+	/// free memory and set number of elements to zero 
+	inline void clear(void)
+	{	length_ = 0;
+		// check if there is old memory to be freed
+		if( capacity_ > 0 )
+			thread_alloc::delete_array(data_);
+		capacity_ = 0;
+	}
+
 	/// vector assignment operator
 	inline vector& operator=(
 		/// right hand size of the assingment operation
 		const vector& x
 	)
 	{	size_t i;
+		// If original lenght is zero, then resize
+		// otherwise a length mismatch is an error.
+		if( length_ == 0 )
+			resize( x.length_ );
 		CPPAD_ASSERT_KNOWN(
 			length_ == x.length_ ,
 			"vector: size miss match in assignment operation"
@@ -590,29 +611,32 @@ public:
 	inline size_t capacity(void) const
 	{	return n_unit_ * bit_per_unit_; }
 
-
 	/// change number of elements in this vector
 	inline void resize(
-		/// new number of elements for this vector, if zero
-		/// make sure the memory is returned to thread_alloc.
+		/// new number of elements for this vector
 		size_t n
 	)
 	{	length_ = n;
 		// check if we can use the current memory
 		size_t min_unit = unit_min();
-		if( (n_unit_ >= min_unit) & (length_ > 0) )
+		if( n_unit_ >= min_unit )
 			return;
 		// check if there is old memory to be freed
 		if( n_unit_ > 0 )
 			thread_alloc::delete_array(data_);
-		// check if we need new memory
-		if( length_ == 0 )
-			n_unit_ = 0;
-		else
-		{	// get new memory and set n_unit
-			data_ = thread_alloc::create_array<UnitType>(min_unit, n_unit_);
-		}
+		// get new memory and set n_unit
+		data_ = thread_alloc::create_array<UnitType>(min_unit, n_unit_);
 	}
+
+	/// free memory and set number of elements to zero
+	inline void clear(void)
+	{	length_ = 0;
+		// check if there is old memory to be freed
+		if( n_unit_ > 0 )
+			thread_alloc::delete_array(data_);
+		n_unit_ = 0;
+	}
+
 	/// vector assignment operator
 	inline vectorBool& operator=(
 		/// right hand size of the assingment operation
@@ -750,5 +774,6 @@ inline std::ostream& operator << (
 	return os;
 }
 
+/*! \} */
 CPPAD_END_NAMESPACE
 # endif
