@@ -1,10 +1,10 @@
-/* $Id: get_started.cpp 2234 2011-12-21 13:44:54Z bradbell $ */
+/* $Id: get_started.cpp 2683 2012-12-30 18:17:03Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -12,7 +12,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 
 /*
 
-$begin ipopt_get_started.cpp$$
+$begin ipopt_nlp_get_started.cpp$$
 $spell
 	cppad_nlp
 	IpoptDir
@@ -42,16 +42,16 @@ $latex \[
 
 $head Configuration Requirement$$
 This example will be compiled and tested provided that
-the value $cref/IpoptDir/InstallUnix/IpoptDir/$$ is specified on the 
-$cref/configure/InstallUnix/Configure/$$ command line.
+a value for $icode ipopt_prefix$$ 
+is specified on the $cref cmake$$ command line. 
 
 $code
-$verbatim%cppad_ipopt/example/get_started.cpp%0%// BEGIN PROGRAM%// END PROGRAM%1%$$
+$verbatim%cppad_ipopt/example/get_started.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
 */
-// BEGIN PROGRAM
+// BEGIN C++
 
 # include <cppad_ipopt_nlp.hpp>
 
@@ -190,4 +190,4 @@ bool ipopt_get_started(void)
 	return ok;
 }
 
-// END PROGRAM
+// END C++
