@@ -1,19 +1,19 @@
-/* $Id: ode_run.hpp 2234 2011-12-21 13:44:54Z bradbell $ */
+/* $Id: ode_run.hpp 2683 2012-12-30 18:17:03Z bradbell $ */
 # ifndef CPPAD_ODE_RUN_INCLUDED
 # define CPPAD_ODE_RUN_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 /*
-$begin ipopt_ode_run.hpp$$
+$begin ipopt_nlp_ode_run.hpp$$
 $spell
 	Ipopt
 $$
@@ -21,13 +21,13 @@ $$
 $section Driver for Running the Ipopt ODE Example$$
 
 $code
-$verbatim%cppad_ipopt/example/ode_run.hpp%0%// BEGIN PROGRAM%// END PROGRAM%1%$$
+$verbatim%cppad_ipopt/example/ode_run.hpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
 */
 
-// BEGIN PROGRAM
+// BEGIN C++
 # include "ode_problem.hpp"
 
 namespace { // BEGIN empty namespace -----------------------------------------
@@ -120,7 +120,7 @@ void ipopt_ode_case(
 	return;
 }
 } // END empty namespace ----------------------------------------------------
-// END PROGRAM
+// END C++
 
 # endif
 
