@@ -14,10 +14,12 @@ var list_down1 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down0 = [
@@ -29,9 +31,7 @@ var list_down0 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_current0 = [
 'adfun.xml#Purpose',
