@@ -38,7 +38,7 @@ var list_down1 = [
 'forward.cpp.xml'
 ];
 var list_down0 = [
-'comparechange.cpp.xml'
+'compare_change.cpp.xml'
 ];
 var list_current0 = [
 'comparechange.xml#Syntax',
