@@ -13,8 +13,8 @@ var list_up0 = [
 'cos.cpp.xml'
 ];
 var list_down3 = [
-'default.xml',
-'ad_copy.xml',
+'ad_ctor.xml',
+'ad_assign.xml',
 'convert.xml',
 'advalued.xml',
 'boolvalued.xml',
