@@ -7,27 +7,53 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
+'appendix.xml',
+'deprecated.xml',
 'cppad_ipopt_nlp.xml'
 ];
-var list_down1 = [
+var list_down3 = [
 'install.xml',
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
 'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'preprocessor.xml',
+'speed.xml',
 'appendix.xml'
 ];
+var list_down2 = [
+'faq.xml',
+'theory.xml',
+'glossary.xml',
+'bib.xml',
+'bugs.xml',
+'wishlist.xml',
+'whats_new.xml',
+'deprecated.xml',
+'compare_c.xml',
+'license.xml'
+];
+var list_down1 = [
+'include_deprecated.xml',
+'fundeprecated.xml',
+'omp_max_thread.xml',
+'tracknewdel.xml',
+'omp_alloc.xml',
+'memory_leak.xml',
+'epsilon.xml',
+'test_vector.xml',
+'cppad_ipopt_nlp.xml'
+];
 var list_down0 = [
-'cppad_ipopt_windows.xml',
-'ipopt_get_started.cpp.xml',
-'cppad_ipopt_ode.xml',
+'ipopt_nlp_get_started.cpp.xml',
+'ipopt_nlp_ode.xml',
 'ipopt_ode_speed.cpp.xml'
 ];
 var list_current0 = [
+'cppad_ipopt_nlp.xml#Deprecated',
 'cppad_ipopt_nlp.xml#Syntax',
 'cppad_ipopt_nlp.xml#Purpose',
 'cppad_ipopt_nlp.xml#cppad_ipopt namespace',
@@ -65,7 +91,6 @@ var list_current0 = [
 'cppad_ipopt_nlp.xml#solution.g',
 'cppad_ipopt_nlp.xml#solution.lambda',
 'cppad_ipopt_nlp.xml#solution.obj_value',
-'cppad_ipopt_nlp.xml#Visual Studio',
 'cppad_ipopt_nlp.xml#Example',
 'cppad_ipopt_nlp.xml#Wish List'
 ];
@@ -81,6 +106,18 @@ function choose_up0(item)
 	if(index > 0)
 		document.location = list_up0[index-1];
 }
+function choose_down3(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down3[index-1];
+}
+function choose_down2(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down2[index-1];
+}
 function choose_down1(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
