@@ -15,10 +15,12 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -26,6 +28,7 @@ var list_down1 = [
 'nearequal.xml',
 'speed_test.xml',
 'speedtest.xml',
+'time_test.xml',
 'numerictype.xml',
 'checknumerictype.xml',
 'simplevector.xml',
@@ -41,28 +44,33 @@ var list_down1 = [
 'odeerrcontrol.xml',
 'odegear.xml',
 'odegearcontrol.xml',
+'cppad_vector.xml',
+'thread_alloc.xml',
+'index_sort.xml',
 'benderquad.xml',
 'opt_val_hes.xml',
-'luratio.xml',
-'std_math_unary.xml',
-'cppad_vector.xml',
-'tracknewdel.xml'
+'luratio.xml'
 ];
 var list_down0 = [
 'cppad_vector.cpp.xml',
-'vectorbool.cpp.xml'
+'vector_bool.cpp.xml'
 ];
 var list_current0 = [
 'cppad_vector.xml#Syntax',
 'cppad_vector.xml#Description',
 'cppad_vector.xml#Include',
+'cppad_vector.xml#capacity',
 'cppad_vector.xml#Assignment',
+'cppad_vector.xml#Assignment.Check Size',
+'cppad_vector.xml#Assignment.Return Reference',
 'cppad_vector.xml#Element Access',
 'cppad_vector.xml#push_back',
 'cppad_vector.xml#push_vector',
 'cppad_vector.xml#Output',
 'cppad_vector.xml#resize',
+'cppad_vector.xml#clear',
 'cppad_vector.xml#vectorBool',
+'cppad_vector.xml#Memory and Parallel Mode',
 'cppad_vector.xml#Example',
 'cppad_vector.xml#Exercise'
 ];
