@@ -15,10 +15,12 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down1 = [
@@ -30,9 +32,7 @@ var list_down1 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_current0 = [
 'dependent.xml#Syntax',
@@ -43,6 +43,7 @@ var list_current0 = [
 'dependent.xml#ADvector',
 'dependent.xml#Taping',
 'dependent.xml#Forward',
+'dependent.xml#Parallel Mode',
 'dependent.xml#Example'
 ];
 function choose_across0(item)
