@@ -16,15 +16,17 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down2 = [
-'default.xml',
-'ad_copy.xml',
+'ad_ctor.xml',
+'ad_assign.xml',
 'convert.xml',
 'advalued.xml',
 'boolvalued.xml',
@@ -36,10 +38,11 @@ var list_down1 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_down0 = [
-'tapeindex.cpp.xml',
+'tape_index.cpp.xml',
 'interp_onetape.cpp.xml',
 'interp_retape.cpp.xml'
 ];
@@ -48,13 +51,14 @@ var list_current0 = [
 'discrete.xml#Purpose',
 'discrete.xml#Base',
 'discrete.xml#name',
-'discrete.xml#u',
-'discrete.xml#v',
 'discrete.xml#x',
 'discrete.xml#y',
+'discrete.xml#ax',
+'discrete.xml#ay',
 'discrete.xml#Create AD Version',
 'discrete.xml#Operation Sequence',
 'discrete.xml#Derivatives',
+'discrete.xml#Parallel Mode',
 'discrete.xml#Example',
 'discrete.xml#Deprecated'
 ];
