@@ -34,7 +34,7 @@ var list_down1 = [
 'revsparsehes.xml'
 ];
 var list_down0 = [
-'forsparsejac.cpp.xml'
+'for_sparse_jac.cpp.xml'
 ];
 var list_current0 = [
 'forsparsejac.xml#Syntax',
