@@ -7,32 +7,45 @@ var list_across0 = [
 ];
 var list_up0 = [
 'cppad.xml',
-'adfun.xml',
+'appendix.xml',
+'deprecated.xml',
 'fundeprecated.xml'
 ];
-var list_down2 = [
+var list_down3 = [
 'install.xml',
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
+var list_down2 = [
+'faq.xml',
+'theory.xml',
+'glossary.xml',
+'bib.xml',
+'bugs.xml',
+'wishlist.xml',
+'whats_new.xml',
+'deprecated.xml',
+'compare_c.xml',
+'license.xml'
+];
 var list_down1 = [
-'independent.xml',
-'funconstruct.xml',
-'dependent.xml',
-'abort_recording.xml',
-'seq_property.xml',
-'funeval.xml',
-'drivers.xml',
-'funcheck.xml',
+'include_deprecated.xml',
+'fundeprecated.xml',
 'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'tracknewdel.xml',
+'omp_alloc.xml',
+'memory_leak.xml',
+'epsilon.xml',
+'test_vector.xml',
+'cppad_ipopt_nlp.xml'
 ];
 var list_current0 = [
 'fundeprecated.xml#Syntax',
@@ -62,6 +75,12 @@ function choose_up0(item)
 	if(index > 0)
 		document.location = list_up0[index-1];
 }
+function choose_down3(item)
+{	var index          = item.selectedIndex;
+	item.selectedIndex = 0;
+	if(index > 0)
+		document.location = list_down3[index-1];
+}
 function choose_down2(item)
 {	var index          = item.selectedIndex;
 	item.selectedIndex = 0;
