@@ -35,7 +35,7 @@ var list_down2 = [
 ];
 var list_down1 = [
 'hessian.cpp.xml',
-'heslagrangian.cpp.xml'
+'hes_lagrangian.cpp.xml'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
