@@ -25,13 +25,12 @@ var list_down2 = [
 'abs.xml',
 'sign.xml',
 'atan2.xml',
-'epsilon.xml',
 'erf.xml',
-'pow.xml'
+'pow.xml',
+'limits.xml'
 ];
 var list_down1 = [
-'pow.cpp.xml',
-'pow_int.cpp.xml'
+'pow.cpp.xml'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
