@@ -35,7 +35,7 @@ var list_down1 = [
 ];
 var list_down0 = [
 'reverse_two.cpp.xml',
-'hestimesdir.cpp.xml'
+'hes_times_dir.cpp.xml'
 ];
 var list_current0 = [
 'reverse_two.xml#Syntax',
