@@ -34,7 +34,7 @@ var list_down1 = [
 'revsparsehes.xml'
 ];
 var list_down0 = [
-'revsparsehes.cpp.xml'
+'rev_sparse_hes.cpp.xml'
 ];
 var list_current0 = [
 'revsparsehes.xml#Syntax',
