@@ -16,10 +16,12 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down2 = [
@@ -31,9 +33,7 @@ var list_down2 = [
 'funeval.xml',
 'drivers.xml',
 'funcheck.xml',
-'omp_max_thread.xml',
-'optimize.xml',
-'fundeprecated.xml'
+'optimize.xml'
 ];
 var list_down1 = [
 'jacobian.xml',
@@ -54,10 +54,14 @@ var list_current0 = [
 'sparse_jacobian.xml#f',
 'sparse_jacobian.xml#x',
 'sparse_jacobian.xml#p',
+'sparse_jacobian.xml#row, col',
 'sparse_jacobian.xml#jac',
+'sparse_jacobian.xml#work',
+'sparse_jacobian.xml#n_sweep',
 'sparse_jacobian.xml#VectorBase',
 'sparse_jacobian.xml#VectorSet',
 'sparse_jacobian.xml#VectorSet.Restrictions',
+'sparse_jacobian.xml#VectorSize',
 'sparse_jacobian.xml#Uses Forward',
 'sparse_jacobian.xml#Example'
 ];
