@@ -16,15 +16,17 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down2 = [
-'default.xml',
-'ad_copy.xml',
+'ad_ctor.xml',
+'ad_assign.xml',
 'convert.xml',
 'advalued.xml',
 'boolvalued.xml',
@@ -36,7 +38,8 @@ var list_down1 = [
 'std_math_ad.xml',
 'mathother.xml',
 'condexp.xml',
-'discrete.xml'
+'discrete.xml',
+'user_atomic.xml'
 ];
 var list_down0 = [
 'acos.cpp.xml',
