@@ -13,8 +13,8 @@ var list_up0 = [
 'unaryplus.xml'
 ];
 var list_down3 = [
-'default.xml',
-'ad_copy.xml',
+'ad_ctor.xml',
+'ad_assign.xml',
 'convert.xml',
 'advalued.xml',
 'boolvalued.xml',
@@ -36,7 +36,7 @@ var list_down1 = [
 'compute_assign.xml'
 ];
 var list_down0 = [
-'unaryplus.cpp.xml'
+'unary_plus.cpp.xml'
 ];
 var list_current0 = [
 'unaryplus.xml#Syntax',
