@@ -16,25 +16,29 @@ var list_down3 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down2 = [
 'faq.xml',
-'speed.xml',
 'theory.xml',
 'glossary.xml',
 'bib.xml',
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
+'compare_c.xml',
 'license.xml'
 ];
 var list_down1 = [
+'whats_new_12.xml',
+'whats_new_11.xml',
 'whats_new_10.xml',
 'whats_new_09.xml',
 'whats_new_08.xml',
