@@ -15,25 +15,29 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down1 = [
 'faq.xml',
-'speed.xml',
 'theory.xml',
 'glossary.xml',
 'bib.xml',
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
+'compare_c.xml',
 'license.xml'
 ];
 var list_down0 = [
+'whats_new_12.xml',
+'whats_new_11.xml',
 'whats_new_10.xml',
 'whats_new_09.xml',
 'whats_new_08.xml',
@@ -45,7 +49,8 @@ var list_down0 = [
 ];
 var list_current0 = [
 'whats_new.xml#Introduction',
-'whats_new.xml#Contents'
+'whats_new.xml#This Year',
+'whats_new.xml#Previous Years'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
