@@ -15,44 +15,42 @@ var list_down2 = [
 'introduction.xml',
 'ad.xml',
 'adfun.xml',
+'preprocessor.xml',
+'multi_thread.xml',
 'library.xml',
-'cppad_ipopt_nlp.xml',
+'ipopt_solve.xml',
 'example.xml',
-'configure.xml',
+'speed.xml',
 'appendix.xml'
 ];
 var list_down1 = [
 'faq.xml',
-'speed.xml',
 'theory.xml',
 'glossary.xml',
 'bib.xml',
 'bugs.xml',
 'wishlist.xml',
 'whats_new.xml',
-'include_deprecated.xml',
+'deprecated.xml',
+'compare_c.xml',
 'license.xml'
 ];
 var list_current0 = [
 'wishlist.xml#Atan2',
 'wishlist.xml#BenderQuad',
-'wishlist.xml#CondExp',
-'wishlist.xml#Ipopt',
+'wishlist.xml#cppad_ipopt_nlp',
+'wishlist.xml#cppad_ipopt_sum',
 'wishlist.xml#Library',
 'wishlist.xml#Multiple Arguments',
 'wishlist.xml#Numeric Limits',
 'wishlist.xml#Operation Sequence',
 'wishlist.xml#Optimization',
 'wishlist.xml#Optimization.Expression Hashing',
-'wishlist.xml#Optimization.Microsoft Compiler',
+'wishlist.xml#Variable Pairs',
 'wishlist.xml#Software Guidelines',
 'wishlist.xml#Software Guidelines.Boost',
-'wishlist.xml#Sparsity Patterns',
-'wishlist.xml#Speed Testing',
-'wishlist.xml#Tan and Tanh',
 'wishlist.xml#Tracing',
-'wishlist.xml#VecAD',
-'wishlist.xml#Vector Element Type'
+'wishlist.xml#user_atomic'
 ];
 function choose_across0(item)
 {	var index          = item.selectedIndex;
