@@ -1,17 +1,17 @@
-/* $Id: ode_gear_control.cpp 1771 2011-01-01 15:41:51Z bradbell $ */
+/* $Id: ode_gear_control.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 
 /*
-$begin OdeGearControl.cpp$$
+$begin ode_gear_control.cpp$$
 $spell
 	Runge
 $$
@@ -23,7 +23,7 @@ $index example, OdeGearControl$$
 $index test, OdeGearControl$$
 
 Define 
-$latex X : \R \rightarrow \R^2$$ by
+$latex X : \B{R} \rightarrow \B{R}^2$$ by
 $latex \[
 \begin{array}{rcl}
 X_0 (t) & = &  - \exp ( - w_0 t )  \\
@@ -40,12 +40,12 @@ $latex \[
 The example tests OdeGearControl using the relations above:
 
 $code
-$verbatim%example/ode_gear_control.cpp%0%// BEGIN PROGRAM%// END PROGRAM%1%$$
+$verbatim%example/ode_gear_control.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
 */
-// BEGIN PROGRAM
+// BEGIN C++
 
 # include <cppad/cppad.hpp>
 # include <cppad/ode_gear_control.hpp>   // CppAD::OdeGearControl
@@ -54,32 +54,32 @@ namespace {
 	// --------------------------------------------------------------
 	class Fun {
 	private:
-		 CPPAD_TEST_VECTOR<double> w;
+		 CPPAD_TESTVECTOR(double) w;
 	public:
 		// constructor
-		Fun(const CPPAD_TEST_VECTOR<double> &w_) : w(w_)
+		Fun(const CPPAD_TESTVECTOR(double) &w_) : w(w_)
 		{ } 
 
 		// set f = x'(t)
 		template <typename Scalar>
 		void Ode(
 			const Scalar                    &t, 
-			const CPPAD_TEST_VECTOR<Scalar> &x, 
-			CPPAD_TEST_VECTOR<Scalar>       &f)
+			const CPPAD_TESTVECTOR(Scalar) &x, 
+			CPPAD_TESTVECTOR(Scalar)       &f)
 		{	f[0] = - w[0] * x[0];
 			f[1] = + w[0] * x[0] - w[1] * x[1];	
 		}
 
 		void Ode_dep(
 			const double                    &t, 
-			const CPPAD_TEST_VECTOR<double> &x, 
-			CPPAD_TEST_VECTOR<double>       &f_x)
+			const CPPAD_TESTVECTOR(double) &x, 
+			CPPAD_TESTVECTOR(double)       &f_x)
 		{	using namespace CppAD;
 
 			size_t n  = x.size();	
-			CPPAD_TEST_VECTOR< AD<double> > T(1);
-			CPPAD_TEST_VECTOR< AD<double> > X(n);
-			CPPAD_TEST_VECTOR< AD<double> > F(n);
+			CPPAD_TESTVECTOR(AD<double>) T(1);
+			CPPAD_TESTVECTOR(AD<double>) X(n);
+			CPPAD_TESTVECTOR(AD<double>) F(n);
 
 			// set argument values
 			T[0] = t;
@@ -97,8 +97,8 @@ namespace {
 			ADFun<double> fun(X, F);
 
 			// compute partial of f w.r.t x
-			CPPAD_TEST_VECTOR<double> dx(n);
-			CPPAD_TEST_VECTOR<double> df(n);
+			CPPAD_TESTVECTOR(double) dx(n);
+			CPPAD_TESTVECTOR(double) df(n);
 			for(j = 0; j < n; j++)
 				dx[j] = 0.;
 			for(j = 0; j < n; j++)
@@ -115,23 +115,23 @@ namespace {
 bool OdeGearControl(void)
 {	bool ok = true;     // initial return value
 
-	CPPAD_TEST_VECTOR<double> w(2);
+	CPPAD_TESTVECTOR(double) w(2);
 	w[0] = 10.;
 	w[1] = 1.;
 	Fun F(w);
 
-	CPPAD_TEST_VECTOR<double> xi(2);
+	CPPAD_TESTVECTOR(double) xi(2);
 	xi[0] = 1.;
 	xi[1] = 0.;
 
-	CPPAD_TEST_VECTOR<double> eabs(2);
+	CPPAD_TESTVECTOR(double) eabs(2);
 	eabs[0] = 1e-4;
 	eabs[1] = 1e-4;
 
 	// return values
-	CPPAD_TEST_VECTOR<double> ef(2);
-	CPPAD_TEST_VECTOR<double> maxabs(2);
-	CPPAD_TEST_VECTOR<double> xf(2);
+	CPPAD_TESTVECTOR(double) ef(2);
+	CPPAD_TESTVECTOR(double) maxabs(2);
+	CPPAD_TESTVECTOR(double) xf(2);
 	size_t                nstep;
 
 	// input values
@@ -157,4 +157,4 @@ bool OdeGearControl(void)
 	return ok;
 }
 
-// END PROGRAM
+// END C++
