@@ -1,10 +1,10 @@
-/* $Id: main.cpp 2233 2011-12-20 19:34:24Z bradbell $ */
+/* $Id: main.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-11 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    GNU General Public License Version 2.
+                    GNU General Public License Version 3.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -15,14 +15,15 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cassert>
 # include <cstddef>
 # include <iostream>
+# include <iomanip>
 # include <cppad/vector.hpp>
 # include <cppad/speed/det_grad_33.hpp>
 # include <cppad/speed/det_33.hpp>
-# include <cppad/speed_test.hpp>
+# include <cppad/time_test.hpp>
 # include <cppad/speed/uniform_01.hpp>
 # include <cppad/poly.hpp>
 # include <cppad/track_new_del.hpp>
-# include <cppad/memory_leak.hpp>
+# include <cppad/thread_alloc.hpp>
 
 # ifdef SPEED_ADOLC
 # define AD_PACKAGE "adolc"
@@ -46,6 +47,9 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 /*
 $begin speed_main$$
 $spell
+	optionlist
+	underbar
+	alloc
 	mat_mul
 	retaped
 	retape
@@ -106,6 +110,7 @@ $cref/correct/speed_main/test/correct/$$,
 $cref/speed/speed_main/test/speed/$$,
 $cref/det_minor/link_det_minor/$$,
 $cref/det_lu/link_det_lu/$$,
+$cref/mat_mul/link_mat_mul/$$,
 $cref/ode/link_ode/$$,
 $cref/poly/link_poly/$$,
 $cref/sparse_hessian/link_sparse_hessian/$$,
@@ -122,7 +127,7 @@ all of the speed tests are run.
 $head seed$$
 $index uniform_01$$
 The command line argument $icode seed$$ is a positive integer.
-The random number simulator $cref/uniform_01/$$ is initialized with
+The random number simulator $cref uniform_01$$ is initialized with
 the call
 $codei%
 	uniform_01(%seed%)
@@ -142,13 +147,24 @@ $codep
 $$
 is true and otherwise it is false.
 If this external symbol is true,
-every test must retape the AD operation sequence for each test repetition.
+every test must retape the 
+$cref/operation sequence/glossary/Operation/Sequence/$$
+for each test repetition.
 If it is false,
-and the particular test has a fixed operation sequence,
 the AD package is allowed to use one taping of the operation
 sequence for all the repetitions of that speed test.
-The following tests have a fixed operation sequence:
-$code det_minor$$, $code mat_mul$$, $code ode$$, $code poly$$.
+$pre
+
+$$
+All of the tests, except $cref/det_lu/link_det_lu/$$,
+have a fixed operations sequence.
+The operation sequence for $code det_lu$$ 
+may be different for each repetition of the test because it
+depends on the matrix for which the determinant is being calculated. 
+For this reason,
+$cref cppad_det_lu.cpp$$ returns false 
+(for test not implemented)
+when $code global_retape$$ is false.
 
 $subhead optimize$$
 If the option $code optimize$$ is present, the symbol
@@ -175,18 +191,46 @@ by adding $cref user_atomic$$ operations,
 this should be included in computations.
 If it is false, user defined atomic operations should not be done.
 
+$subhead memory$$
+If the option $code memory$$ is present, the symbol
+$codep
+	extern bool global_memory
+$$
+is true and otherwise it is false.
+If it is true, the CppAD
+$cref/hold_memory/ta_hold_memory/$$ routine will be called by 
+the main program before any of the tests are executed.
+This should make the CppAD $code thread_alloc$$ allocator faster.
+If it is false, standard memory allocation should be done by.
+Otherwise the test can use special memory allocation to try 
+and improve speed.
+
 $head Correctness Results$$
-An output line is generated for each correctness test
-stating of the test passed or failed.
+An output line of the following form:
+$codei%
+	%package%_%test%_%optionlist%_ok = %flag%
+%$$
+is generated for each correctness test where
+$icode package$$ and $icode test$$ are as above,
+$icode optionlist$$ are the options (in $icode option_list$$) 
+separated by the underbar $code _$$ character
+(whereas they are separated by spaces in $icode option_list$$),
+and $icode flag$$ is $code true$$ or $code false$$.
 
 $head Speed Results$$
-For each speed test, corresponds to three lines of output.
-The name of the package and test are printed on the first line,
-the vector of problem sizes are printed on the next line,
-and the rates corresponding to the different problem sizes are
-printed on the third line.
-The rate is the number of times per second that the calculation was repeated.
-
+For each speed test, corresponds to three lines of the
+following form are generated:
+$codei%
+	%package%_%test%_%optionlist%_ok   = %flag%
+	%package%_%test%_%optionlist%_size = [ %size_1%, %...%, %size_n% ]
+	%package%_%test%_%optionlist%_rate = [ %rate_1%, %...%, %rate_n% ]
+%$$
+The values $icode package$$, $icode test$$, $icode optionlist$$,
+and $icode flag$$ are as in the correctness results above.
+The values $icode size_1$$, ..., $icode size_n$$ are the
+size arguments used for the corresponding tests.
+The values $icode rate_1$$, ..., $icode rate_n$$ are the number of times
+per second that the corresponding size problem executed.
 
 $children%
 	speed/src/link_det_lu.cpp%
@@ -205,6 +249,7 @@ functions that link the speed test to the main program described above:
 $table
 $rref link_det_lu$$
 $rref link_det_minor$$
+$rref link_mat_mul$$
 $rref link_ode$$
 $rref link_poly$$
 $rref link_sparse_hessian$$
@@ -232,10 +277,22 @@ CPPAD_DECLARE_SPEED(sparse_jacobian);
 bool   global_retape;
 bool   global_optimize;
 bool   global_atomic;
+bool   global_memory;
 
 namespace {
 	using std::cout;
 	using std::endl;
+	// ----------------------------------------------------------------
+	// not available test message
+	void not_available_message(const char* test_name)
+	{	cout << AD_PACKAGE << ": " << test_name;
+		cout << " is not availabe with " << endl;
+		cout << "global_retape = " << global_retape;
+		cout << ", global_optimize = " << global_optimize;
+		cout << ", global_atomic = " << global_atomic;
+		cout << ", global_memory = " << global_memory;
+		cout << endl;
+	}
 
 	// ------------------------------------------------------
 	// output vector in form readable by octave or matlab
@@ -257,12 +314,21 @@ namespace {
 	static size_t Run_error_count = 0;
 	bool run_correct(bool correct_case(bool), const char *case_name)
 	{	bool ok;
-		cout << AD_PACKAGE << "_" << case_name << "_ok = ";
 # ifdef SPEED_DOUBLE
 		ok = correct_case(true);
 # else
 		ok = correct_case(false);
 # endif
+		cout << AD_PACKAGE << "_" << case_name;
+		if( global_retape )
+			cout << "_retape";
+		if( global_optimize )
+			cout << "_optimize";
+		if( global_atomic )
+			cout << "_atomic";
+		if( global_memory )
+			cout << "_memory";
+		cout << "_ok = ";
 		if( ok )
 		{	cout << " true" << endl;
 			Run_ok_count++;
@@ -283,12 +349,31 @@ namespace {
 		cout << AD_PACKAGE << "_" << case_name << "_size = ";
 		output(size_vec);
 		cout << endl;
+		cout << AD_PACKAGE << "_" << case_name;
+		if( global_retape )
+			cout << "_retape";
+		if( global_optimize )
+			cout << "_optimize";
+		if( global_atomic )
+			cout << "_atomic";
+		if( global_memory )
+			cout << "_memory";
+		cout << "_rate = ";
 
-		CppAD::vector<size_t> rate_vec( size_vec.size() );
-		rate_vec = CppAD::speed_test(speed_case, size_vec, time_min);
-		cout << AD_PACKAGE << "_" << case_name << "_rate = ";
-		output(rate_vec);
-		cout << endl;
+		cout << std::fixed;
+		for(size_t i = 0; i < size_vec.size(); i++)
+		{	if( i == 0 )
+				cout << "[ ";
+			else	cout << ", ";	
+			cout << std::flush;
+			size_t size = size_vec[i];
+			double time = CppAD::time_test(speed_case, time_min, size);
+			double rate = 1. / time;
+			if( rate >= 1000 )
+				cout << std::setprecision(0) << rate;
+			else cout << std::setprecision(2) << rate;
+		}
+		cout << " ]" << endl;
 		return;
 	}
 }
@@ -339,6 +424,7 @@ int main(int argc, char *argv[])
 		global_retape   = false;
 		global_optimize = false;
 		global_atomic   = false;
+		global_memory   = false;
 		for(i = 3; i < size_t(argc); i++)
 		{	if( strcmp(argv[i], "retape") == 0 )
 				global_retape = true;
@@ -346,6 +432,8 @@ int main(int argc, char *argv[])
 				global_optimize = true;
 			else if( strcmp(argv[i], "atomic") == 0 )
 				global_atomic = true;
+			else if( strcmp(argv[i], "memory") == 0 )
+				global_memory = true;
 			else
 				error = true;
 		}
@@ -359,9 +447,14 @@ int main(int argc, char *argv[])
 		cout << "seed choices: ";
 		cout << "a positive integer used as a random seed." << endl;
 		cout << "option choices: ";
-		cout << " \"retape\", \"optimize\"." << endl << endl;
+		cout << " \"retape\",";
+		cout << " \"optimize\",";
+		cout << " \"atomic\",";
+		cout << " \"memory\"." << endl << endl;
 		return 1;
 	}
+	if( global_memory )
+		CppAD::thread_alloc::hold_memory(true);
 
 	// initialize the random number simulator
 	CppAD::uniform_01(size_t(iseed));
@@ -379,10 +472,10 @@ int main(int argc, char *argv[])
 	{	size_det_lu[i]      = 3 * i + 1;
 		size_det_minor[i]   = i + 1;
 		size_mat_mul[i]     = 10 * (i + 1);
-		size_ode[i]         = i + 1;
+		size_ode[i]         = 3 * i + 1;
 		size_poly[i]        = 8 * i + 1;
-		size_sparse_hessian[i]  = 30 * (i + 1);
-		size_sparse_jacobian[i] = 30 * (i + 1);
+		size_sparse_hessian[i]  = 100 * (i + 1) * (i + 1);
+		size_sparse_jacobian[i] = 100 * (i + 1) * (i + 1);
 	}
 
 	switch(match)
@@ -431,7 +524,7 @@ int main(int argc, char *argv[])
 		speed_det_minor,       size_det_minor,       "det_minor"
 		);
 		if( available_mat_mul() ) run_speed(
-		speed_mat_mul,           size_mat_mul,       "det_minor"
+		speed_mat_mul,           size_mat_mul,       "mat_mul"
 		);
 		if( available_ode() ) run_speed(
 		speed_ode,             size_ode,             "ode"
@@ -451,8 +544,7 @@ int main(int argc, char *argv[])
 
 		case test_det_lu:
 		if( ! available_det_lu() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_det_lu,           "det_lu");
@@ -462,8 +554,7 @@ int main(int argc, char *argv[])
 
 		case test_det_minor:
 		if( ! available_det_minor() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_det_minor,       "det_minor");
@@ -473,8 +564,7 @@ int main(int argc, char *argv[])
 
 		case test_mat_mul:
 		if( ! available_mat_mul() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_mat_mul,     "mat_mul");
@@ -484,8 +574,7 @@ int main(int argc, char *argv[])
 
 		case test_ode:
 		if( ! available_ode() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_ode,           "ode");
@@ -495,8 +584,7 @@ int main(int argc, char *argv[])
 
 		case test_poly:
 		if( ! available_poly() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_poly,            "poly");
@@ -506,8 +594,7 @@ int main(int argc, char *argv[])
 
 		case test_sparse_hessian:
 		if( ! available_sparse_hessian() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_sparse_hessian, "sparse_hessian");
@@ -518,8 +605,7 @@ int main(int argc, char *argv[])
 
 		case test_sparse_jacobian:
 		if( ! available_sparse_jacobian() )
-		{	cout << AD_PACKAGE << ": test " << argv[1] 
-			     << " not available" << endl; 
+		{	not_available_message( argv[1] ); 
 			exit(1);
 		}
 		ok &= run_correct(correct_sparse_jacobian, "sparse_jacobian");
@@ -534,23 +620,23 @@ int main(int argc, char *argv[])
 	}
 # ifndef NDEBUG
 	// return memory for vectors that are still in scope
-	size_det_lu.resize(0);
-	size_det_minor.resize(0);
-	size_mat_mul.resize(0);
-	size_ode.resize(0);
-	size_poly.resize(0);
-	size_sparse_hessian.resize(0);
-	size_sparse_jacobian.resize(0);
+	size_det_lu.clear();
+	size_det_minor.clear();
+	size_mat_mul.clear();
+	size_ode.clear();
+	size_poly.clear();
+	size_sparse_hessian.clear();
+	size_sparse_jacobian.clear();
 	// check for memory leak
-	if( CppAD::memory_leak() )
+	if( CppAD::thread_alloc::free_all() )
+	{	Run_ok_count++;
+		cout << "No memory leak detected" << endl;
+	}
+	else
 	{	ok = false;
 		Run_error_count++;
 		cout << "Memory leak detected" << endl;
 	}
-	else
-	{	Run_ok_count++;
-		cout << "No memory leak detected" << endl;
-	}
 # endif
 	return static_cast<int>( ! ok );
 }
